@@ -56,6 +56,7 @@ const QString NoPasswordVisable = "nopasswd-login-visable";
 AccountsWorker::AccountsWorker(UserModel *userList, QObject *parent)
     : QObject(parent)
     , m_accountsInter(new Accounts(AccountsService, "/com/deepin/daemon/Accounts", QDBusConnection::systemBus(), this))
+    , m_syncHelperInter(new QDBusInterface("com.deepin.sync.Helper", "/com/deepin/sync/Helper", "com.deepin.sync.Helper", QDBusConnection::systemBus(), this))
     , m_fingerPrint(new Fingerprint(FingerPrintService, "/com/deepin/daemon/Authenticate/Fingerprint", QDBusConnection::systemBus(), this))
 #ifdef DCC_ENABLE_ADDOMAIN
     , m_notifyInter(new Notifications("org.freedesktop.Notifications", "/org/freedesktop/Notifications", QDBusConnection::sessionBus(), this))
@@ -66,6 +67,7 @@ AccountsWorker::AccountsWorker(UserModel *userList, QObject *parent)
     struct passwd *pws;
     pws = getpwuid(getuid());
     m_currentUserName = QString(pws->pw_name);
+    m_userModel->setCurrentUserName(m_currentUserName);
 
     connect(m_accountsInter, &Accounts::UserListChanged, this, &AccountsWorker::onUserListChanged, Qt::QueuedConnection);
     connect(m_accountsInter, &Accounts::UserAdded, this, &AccountsWorker::addUser, Qt::QueuedConnection);
@@ -79,6 +81,10 @@ AccountsWorker::AccountsWorker(UserModel *userList, QObject *parent)
     m_notifyInter->setSync(false);
 #endif
     QDBusInterface interface(AccountsService, "/com/deepin/daemon/Accounts", AccountsService, QDBusConnection::systemBus());
+    QList<QVariant> currentUserPath = interface.call("FindUserById", QString::number(pws->pw_uid)).arguments();
+    if (!currentUserPath.isEmpty()) {
+        onUserListChanged({currentUserPath.first().toString()});
+    }
     onUserListChanged(interface.property("UserList").toStringList());
     updateUserOnlineStatus(m_dmInter->sessions());
     getAllGroups();
@@ -143,6 +149,67 @@ void AccountsWorker::getPresetGroupsResult(QDBusPendingCallWatcher *watch)
     watch->deleteLater();
 }
 
+void AccountsWorker::getUOSID(QString &uosid)
+{
+    if (!m_syncHelperInter->isValid()) {
+        qWarning() << "syncHelper interface invalid: (getUOSID)" << m_syncHelperInter->lastError().message();
+        return;
+    }
+    QDBusReply<QString> retUOSID = m_syncHelperInter->call("UOSID");
+    if (retUOSID.error().message().isEmpty()) {
+        uosid = retUOSID.value();
+    } else {
+        qWarning() << "UOSID failed:" << retUOSID.error().message();
+        return;
+    }
+}
+
+void AccountsWorker::getUUID(QString &uuid)
+{
+    QDBusInterface accountsInter("com.deepin.daemon.Accounts",
+                                 QString("/com/deepin/daemon/Accounts/User%1").arg(getuid()),
+                                 "com.deepin.daemon.Accounts.User",
+                                 QDBusConnection::systemBus());
+    if (!accountsInter.isValid()) {
+        qWarning() << "accountsInter invalid: (getUUID)" << accountsInter.lastError().message();
+        return;
+    }
+    QVariant retUUID = accountsInter.property("UUID");
+    uuid = retUUID.toString();
+}
+
+void AccountsWorker::localBindCheck(dcc::accounts::User *user, const QString &uosid, const QString &uuid)
+{
+    QFutureWatcher<BindCheckResult> *watcher = new QFutureWatcher<BindCheckResult>(this);
+    connect(watcher, &QFutureWatcher<BindCheckResult>::finished, [this, watcher] {
+        BindCheckResult result = watcher->result();
+        if (result.error.isEmpty())
+            Q_EMIT localBindUbid(result.ubid);
+        else
+            Q_EMIT localBindError(result.error);
+        watcher->deleteLater();
+    });
+    QFuture<BindCheckResult> future = QtConcurrent::run(this, &AccountsWorker::checkLocalBind, uosid, uuid);
+    watcher->setFuture(future);
+}
+
+void AccountsWorker::startResetPasswordExec(User *user)
+{
+    qDebug() << "Begin Resetpassword";
+    AccountsUser *userInter = m_userInters.value(user);
+    auto reply = userInter->SetPassword("");
+    reply.waitForFinished();
+    Q_EMIT user->startResetPasswordReplied(reply.error().message());
+}
+
+void AccountsWorker::setPasswordHint(User *user, const QString &passwordHint)
+{
+    AccountsUser *userInter = m_userInters.value(user);
+    Q_ASSERT(userInter);
+
+    userInter->SetPasswordHint(passwordHint);
+}
+
 void AccountsWorker::setGroups(User *user, const QStringList &usrGroups)
 {
     AccountsUser *userInter = m_userInters[user];
@@ -154,12 +221,14 @@ void AccountsWorker::setGroups(User *user, const QStringList &usrGroups)
 void AccountsWorker::active()
 {
     for (auto it(m_userInters.cbegin()); it != m_userInters.cend(); ++it) {
-        it.key()->setName(it.value()->userName());
+        it.key()->setName(it.value()->property("UserName").toString());
         it.key()->setAutoLogin(it.value()->automaticLogin());
+        it.key()->setUserType(it.value()->accountType());
         it.key()->setAvatars(it.value()->iconList());
         it.key()->setGroups(it.value()->groups());
         it.key()->setCurrentAvatar(it.value()->iconFile());
         it.key()->setCreatedTime(it.value()->createdTime());
+        it.key()->setGid(it.value()->gid());
     }
 }
 
@@ -168,6 +237,13 @@ QString AccountsWorker::getCurrentUserName()
     return m_currentUserName;
 }
 
+QDBusPendingReply<bool, QString, int> AccountsWorker::isUsernameValid(const QString &name)
+{
+    QDBusPendingReply<bool, QString, int> reply = m_accountsInter->IsUsernameValid(name);
+    reply.waitForFinished();
+    return reply;
+}
+
 void AccountsWorker::randomUserIcon(User *user)
 {
     QDBusPendingCall call = m_accountsInter->RandUserIcon();
@@ -201,6 +277,11 @@ void AccountsWorker::createAccount(const User *user)
     watcher->setFuture(future);
 }
 
+void AccountsWorker::updateGroupinfo()
+{
+    m_userModel->setAllGroups(m_accountsInter->GetGroups());
+}
+
 void AccountsWorker::setAvatar(User *user, const QString &iconPath)
 {
     qDebug() << "set account avatar";
@@ -231,30 +312,39 @@ void AccountsWorker::setFullname(User *user, const QString &fullname)
 
 void AccountsWorker::deleteAccount(User *user, const bool deleteHome)
 {
-    QDBusPendingReply<> reply = m_accountsInter->DeleteUser(user->name(), deleteHome);
-    reply.waitForFinished();
-    if (reply.isError()) {
-        qDebug() << Q_FUNC_INFO << reply.error().message();
-        Q_EMIT m_userModel->isCancelChanged();
-    } else {
-        Q_EMIT m_userModel->deleteUserSuccess();
-        removeUser(m_userInters.value(user)->path());
-        getAllGroups();
-
-        QDBusPendingReply<> listFingersReply = m_fingerPrint->ListFingers(user->name());
-        listFingersReply.waitForFinished();
-        if (listFingersReply.isError()) {
-            qDebug() << Q_FUNC_INFO << listFingersReply.error().message();
+    QDBusPendingCall call = m_accountsInter->DeleteUser(user->name(), deleteHome);
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this, user] (QDBusPendingCallWatcher* call) {
+        Q_EMIT requestMainWindowEnabled(true);
+        if (call->isError()) {
+            qDebug() << Q_FUNC_INFO << call->error().message();
+            Q_EMIT m_userModel->isCancelChanged();
         } else {
-            if (m_fingerPrint->ListFingers(user->name()).value().count()) {
-                QDBusPendingReply<> delAllFingereply = m_fingerPrint->DeleteAllFingers(user->name());
-                delAllFingereply.waitForFinished();
-                if (delAllFingereply.isError()) {
-                    qDebug() << Q_FUNC_INFO << delAllFingereply.error().message();
+            if (!m_userInters.contains(user)) {
+                call->deleteLater();
+                return;
+            }
+            Q_EMIT m_userModel->deleteUserSuccess();
+            removeUser(m_userInters.value(user)->path());
+            getAllGroups();
+
+            QDBusPendingReply<> listFingersReply = m_fingerPrint->ListFingers(user->name());
+            listFingersReply.waitForFinished();
+            if (listFingersReply.isError()) {
+                qDebug() << Q_FUNC_INFO << listFingersReply.error().message();
+            } else {
+                if (m_fingerPrint->ListFingers(user->name()).value().count()) {
+                    QDBusPendingReply<> delAllFingereply = m_fingerPrint->DeleteAllFingers(user->name());
+                    delAllFingereply.waitForFinished();
+                    if (delAllFingereply.isError()) {
+                        qDebug() << Q_FUNC_INFO << delAllFingereply.error().message();
+                    }
                 }
             }
         }
-    }
+        call->deleteLater();
+    });
+    Q_EMIT requestMainWindowEnabled(false);
 }
 
 void AccountsWorker::setAutoLogin(User *user, const bool autoLogin)
@@ -277,6 +367,32 @@ void AccountsWorker::setAutoLogin(User *user, const bool autoLogin)
     });
 }
 
+//切换账户权限
+void AccountsWorker::setAdministrator(User *user, const bool asAdministrator)
+{
+    AccountsUser *ui = m_userInters[user];
+    Q_ASSERT(ui);
+
+    // because this operate need root permission, we must wait for finished and refersh result
+    Q_EMIT requestMainWindowEnabled(false);
+
+    QStringList lstGroups = ui->groups();
+    if(!asAdministrator)
+        lstGroups.removeOne("sudo");
+    else
+        lstGroups.append("sudo");
+
+    QDBusPendingCall call = ui->SetGroups(lstGroups);
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [=] {
+        if (call.isError()) {
+            Q_EMIT user->userTypeChanged(user->userType());
+        }
+        Q_EMIT requestMainWindowEnabled(true);
+        watcher->deleteLater();
+    });
+}
+
 void AccountsWorker::loadUserList()
 {
     onUserListChanged(m_accountsInter->userList());
@@ -300,25 +416,38 @@ void AccountsWorker::onUserListChanged(const QStringList &userList)
     }
 }
 
-void AccountsWorker::setPassword(User *user, const QString &oldpwd, const QString &passwd, const QString &repeatPasswd)
+void AccountsWorker::setPassword(User *user, const QString &oldpwd, const QString &passwd, const QString &repeatPasswd, const bool needResult)
 {
     QProcess process;
-    QProcessEnvironment env;
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
     env.insert("LC_ALL", "C");
     process.setProcessEnvironment(env);
+    process.setProcessChannelMode(QProcess::MergedChannels);
+
     process.start("/bin/bash", QStringList() << "-c" << QString("passwd"));
     if (user->passwordStatus() == NO_PASSWORD) {
         process.write(QString("%1\n%2\n").arg(passwd).arg(repeatPasswd).toLatin1());
     } else {
         process.write(QString("%1\n%2\n%3").arg(oldpwd).arg(passwd).arg(repeatPasswd).toLatin1());
     }
+
     process.closeWriteChannel();
     process.waitForFinished();
 
-    // process.exitCode() = 0 表示密码修改成功
-    int exitCode = process.exitCode();
-    QString errorTxt = process.readAllStandardError();
-    Q_EMIT user->passwordModifyFinished(exitCode, errorTxt);
+    if (needResult) {
+        // process.exitCode() = 0 表示密码修改成功
+        int exitCode = process.exitCode();
+        const QString& outputTxt = process.readAll();
+        Q_EMIT user->passwordModifyFinished(exitCode, outputTxt);
+    }
+}
+
+void AccountsWorker::resetPassword(User *user, const QString &password)
+{
+    auto reply = m_userInters.value(user)->SetPassword(cryptUserPassword(password));
+    reply.waitForFinished();
+
+    Q_EMIT user->passwordResetFinished(reply.error().message());
 }
 
 void AccountsWorker::deleteUserIcon(User *user, const QString &iconPath)
@@ -331,7 +460,7 @@ void AccountsWorker::deleteUserIcon(User *user, const QString &iconPath)
 
 void AccountsWorker::addUser(const QString &userPath)
 {
-    if (userPath.contains("User0", Qt::CaseInsensitive))
+    if (userPath.contains("User0", Qt::CaseInsensitive) || m_userModel->contains(userPath))
         return;
     AccountsUser *userInter = new AccountsUser(AccountsService, userPath, QDBusConnection::systemBus(), this);
     userInter->setSync(false);
@@ -357,6 +486,7 @@ void AccountsWorker::addUser(const QString &userPath)
     connect(userInter, &AccountsUser::GroupsChanged, user, &User::setGroups);
     connect(userInter, &AccountsUser::AccountTypeChanged, user, &User::setUserType);
     connect(userInter, &AccountsUser::MaxPasswordAgeChanged, user, &User::setPasswordAge);
+    connect(userInter, &AccountsUser::GidChanged, user, &User::setGid);
 
     // 这里直接赋值的话, 由于请求是异步的, 所以一开始会被初始化成乱码,
     // 然后数据正常了以后会额外产生一次变化信号
@@ -373,6 +503,7 @@ void AccountsWorker::addUser(const QString &userPath)
     userInter->accountType();
     userInter->maxPasswordAge();
     userInter->IsPasswordExpired();
+    userInter->gid();
 
     m_userInters[user] = userInter;
     m_userModel->addUser(userPath, user);
@@ -608,11 +739,13 @@ CreationResult *AccountsWorker::createAccountInternal(const User *user)
     bool sifResult = !userDBus->SetIconFile(user->currentAvatar()).isError();
     bool spResult = !userDBus->SetPassword(cryptUserPassword(user->password())).isError();
     bool groupResult = true;
+    bool passwordHintResult = true;
     if (IsServerSystem && !user->groups().isEmpty()) {
         groupResult = !userDBus->SetGroups(user->groups()).isError();
     }
+    passwordHintResult = !userDBus->SetPasswordHint(user->passwordHint()).isError();
 
-    if (!sifResult || !spResult || !groupResult) {
+    if (!sifResult || !spResult || !groupResult || !passwordHintResult) {
         result->setType(CreationResult::UnknownError);
         if (!sifResult)
             result->setMessage("set icon file for new created user failed.");
@@ -648,3 +781,20 @@ QString AccountsWorker::cryptUserPassword(const QString &password)
 
     return crypt(password.toUtf8().data(), salt);
 }
+
+BindCheckResult AccountsWorker::checkLocalBind(const QString &uosid, const QString &uuid)
+{
+    BindCheckResult result;
+    QDBusReply<QString> retLocalBindCheck= m_syncHelperInter->call(QDBus::BlockWithGui, "LocalBindCheck", uosid, uuid);
+    if (!m_syncHelperInter->isValid()) {
+        qWarning() << "syncHelper interface invalid: (localBindCheck)" << m_syncHelperInter->lastError().message();
+        return result;
+    }
+    if (retLocalBindCheck.error().message().isEmpty()) {
+        result.ubid = retLocalBindCheck.value();
+    } else {
+        qWarning() << "localBindCheck failed:" << retLocalBindCheck.error().message();
+        result.error = retLocalBindCheck.error().message();
+    }
+    return result;
+}
