@@ -33,11 +33,15 @@
 namespace dcc {
 namespace bluetooth {
 
-BluetoothWorker::BluetoothWorker(BluetoothModel *model, bool sync) :
-    QObject(),
-    m_bluetoothInter(new DBusBluetooth("com.deepin.daemon.Bluetooth", "/com/deepin/daemon/Bluetooth", QDBusConnection::sessionBus(), this)),
-    m_model(model)
+BluetoothWorker::BluetoothWorker(BluetoothModel *model, bool sync)
+    : QObject()
+    , m_bluetoothInter(new DBusBluetooth("com.deepin.daemon.Bluetooth", "/com/deepin/daemon/Bluetooth", QDBusConnection::sessionBus(), this))
+    , m_airPlaneModeInter(new DBusAirplaneMode("com.deepin.daemon.AirplaneMode", "/com/deepin/daemon/AirplaneMode", QDBusConnection::systemBus(), this))
+    , m_model(model)
+    , m_connectingAudioDevice(false)
+    , m_state(m_bluetoothInter->state())
 {
+    connect(m_bluetoothInter, &DBusBluetooth::StateChanged, this, &BluetoothWorker::onStateChanged);
     connect(m_bluetoothInter, &DBusBluetooth::AdapterAdded, this, &BluetoothWorker::addAdapter);
     connect(m_bluetoothInter, &DBusBluetooth::AdapterRemoved, this, &BluetoothWorker::removeAdapter);
     connect(m_bluetoothInter, &DBusBluetooth::AdapterPropertiesChanged, this, &BluetoothWorker::onAdapterPropertiesChanged);
@@ -91,9 +95,35 @@ BluetoothWorker::BluetoothWorker(BluetoothModel *model, bool sync) :
     });
 
     connect(m_bluetoothInter, &DBusBluetooth::TransportableChanged, m_model, &BluetoothModel::setTransportable);
+    connect(m_bluetoothInter, &DBusBluetooth::CanSendFileChanged, m_model, &BluetoothModel::setCanSendFile);
+
+    /*FIXME
+     * 这里关联的信号有时候收不到是因为 qt-dbus-factory 中的 changed 的信号有时候会发不出来，
+     * qt-dbus-factory 中的 DBusExtendedAbstractInterface::internalPropGet 在同步调用情况下，会将缓存中的数据写入属性中，
+     * 导致后面 onPropertyChanged 中的判断认为属性值没变，就没有发出 changed 信号。
+     * 建议：前端仅在初始化时主动获取一次 dbus 中的值存储在成员变量中，并建立 changed 信号连接，后面所有用到那个值的地方，均获取成员变量;
+    */
+
+#if 0
+//    connect(m_bluetoothInter, &DBusBluetooth::DisplaySwitchChanged, m_model, &BluetoothModel::setDisplaySwitch);
+#else
+    QDBusConnection::sessionBus().connect("com.deepin.daemon.Bluetooth",
+                                          "/com/deepin/daemon/Bluetooth",
+                                          "org.freedesktop.DBus.Properties",
+                                          "PropertiesChanged",
+                                          "sa{sv}as",
+                                          this, SLOT(handleDbusSignal(QDBusMessage)));
+#endif
+
     m_model->setTransportable(m_bluetoothInter->transportable());
+    m_model->setCanSendFile(m_bluetoothInter->canSendFile());
+    m_model->setDisplaySwitch(m_bluetoothInter->displaySwitch());
+
+    connect(m_airPlaneModeInter, &DBusAirplaneMode::EnabledChanged, m_model, &BluetoothModel::setAirplaneEnable);
+    m_model->setAirplaneEnable(m_airPlaneModeInter->enabled());
 
     m_bluetoothInter->setSync(sync);
+    m_airPlaneModeInter->setSync(sync);
 
     //第一次调用时传true，refresh 函数会使用同步方式去获取蓝牙设备数据
     //避免出现当dbus调用控制中心接口直接显示蓝牙模块时，
@@ -109,6 +139,15 @@ BluetoothWorker::~BluetoothWorker()
 
 }
 
+void BluetoothWorker::onStateChanged(uint state)
+{
+    //当蓝牙状态由0变成大于0时，强制刷新蓝牙列表
+    if (!m_state && state > 0)
+        refresh(true);
+
+    m_state = state;
+}
+
 BluetoothWorker &BluetoothWorker::Instance(bool sync)
 {
     static BluetoothWorker worker(new BluetoothModel, sync);
@@ -214,6 +253,9 @@ void BluetoothWorker::ignoreDevice(const Adapter *adapter, const Device *device)
 
 void BluetoothWorker::connectDevice(const Device *device, const Adapter *adapter)
 {
+    if (m_connectingAudioDevice && device->deviceType() == "pheadset") {
+            return;
+    }
     for (const Adapter *a : m_model->adapters()) {
         for (const Device *d : a->devices()) {
             Device *vd = const_cast<Device*>(d);
@@ -301,6 +343,10 @@ void BluetoothWorker::inflateDevice(Device *device, const QJsonObject &deviceObj
     const bool connectState = deviceObj["ConnectState"].toBool();
     const QString icon = deviceObj["Icon"].toString();
 
+    if (icon == "audio-card") {
+        m_connectingAudioDevice = (Device::StateAvailable == state);
+    }
+
     // FIXME: If the name and alias of the Bluetooth device are both empty, it will not be updated by default.
     // To solve the problem of blank device name display.
     if (alias.isEmpty() && name.isEmpty())
@@ -476,5 +522,29 @@ void BluetoothWorker::onRequestSetDiscoverable(const Adapter *adapter, const boo
     m_bluetoothInter->SetAdapterDiscoverable(path, discoverable);
 }
 
+void BluetoothWorker::setDisplaySwitch(const bool &on)
+{
+    m_bluetoothInter->setDisplaySwitch(on);
+}
+
+void BluetoothWorker::handleDbusSignal(QDBusMessage mes)
+{
+    QList<QVariant> arguments = mes.arguments();
+    if (3 != arguments.count()) {
+        return;
+    }
+    QString interfaceName = mes.arguments().at(0).toString();
+    if (interfaceName == "com.deepin.daemon.Bluetooth") {
+        QVariantMap changedProps = qdbus_cast<QVariantMap>(arguments.at(1).value<QDBusArgument>());
+        QStringList keys = changedProps.keys();
+        for (int i = 0; i < keys.size(); i++) {
+            if (keys.at(i) == "DisplaySwitch") {
+                bool state = static_cast<bool>(changedProps.value(keys.at(i)).toBool());
+                m_model->setDisplaySwitch(state);
+            }
+        }
+    }
+}
+
 } // namespace bluetooth
 } // namespace dcc
