@@ -51,10 +51,13 @@ DisplayWorker::DisplayWorker(DisplayModel *model, QObject *parent, bool isSync)
                                             "/com/deepin/daemon/Appearance",
                                             QDBusConnection::sessionBus(), this))
     , m_updateScale(false)
+    , m_timer(new QTimer(this))
     , m_powerInter(new PowerInter("com.deepin.daemon.Power", "/com/deepin/daemon/Power", QDBusConnection::sessionBus(), this))
 {
     m_displayInter.setSync(isSync);
     m_appearanceInter->setSync(isSync);
+    m_timer->setSingleShot(true);
+    m_timer->setInterval(200);
 
     m_displayDBusInter = new QDBusInterface("com.deepin.daemon.Display",
                                             "/com/deepin/daemon/Display",
@@ -64,7 +67,7 @@ DisplayWorker::DisplayWorker(DisplayModel *model, QObject *parent, bool isSync)
     connect(&m_displayInter, &DisplayInter::MonitorsChanged, this, &DisplayWorker::onMonitorListChanged);
     connect(&m_displayInter, &DisplayInter::BrightnessChanged, this, &DisplayWorker::onMonitorsBrightnessChanged);
     connect(&m_displayInter, &DisplayInter::BrightnessChanged, model, &DisplayModel::setBrightnessMap);
-    connect(&m_displayInter, &DisplayInter::TouchscreensChanged, model, &DisplayModel::setTouchscreenList);
+    connect(&m_displayInter, &DisplayInter::TouchscreensV2Changed, model, &DisplayModel::setTouchscreenList);
     connect(&m_displayInter, &DisplayInter::TouchMapChanged, model, &DisplayModel::setTouchMap);
     connect(&m_displayInter, &DisplayInter::ScreenHeightChanged, model, &DisplayModel::setScreenHeight);
     connect(&m_displayInter, &DisplayInter::ScreenWidthChanged, model, &DisplayModel::setScreenWidth);
@@ -77,6 +80,10 @@ DisplayWorker::DisplayWorker(DisplayModel *model, QObject *parent, bool isSync)
     //display redSfit/autoLight
     connect(m_powerInter, &PowerInter::HasAmbientLightSensorChanged, m_model, &DisplayModel::autoLightAdjustVaildChanged);
     connect(m_dccSettings, &QGSettings::changed, this, &DisplayWorker::onGSettingsChanged);
+    connect(m_timer, &QTimer::timeout, this, [=] {
+        m_displayInter.ApplyChanges().waitForFinished();
+        m_displayInter.Save().waitForFinished();
+    });
 }
 
 DisplayWorker::~DisplayWorker()
@@ -104,7 +111,7 @@ void DisplayWorker::active()
     onMonitorListChanged(m_displayInter.monitors());
 
     m_model->setDisplayMode(m_displayInter.displayMode());
-    m_model->setTouchscreenList(m_displayInter.touchscreens());
+    m_model->setTouchscreenList(m_displayInter.touchscreensV2());
     m_model->setTouchMap(m_displayInter.touchMap());
     m_model->setPrimary(m_displayInter.primary());
     m_model->setScreenHeight(m_displayInter.screenHeight());
@@ -216,18 +223,19 @@ void DisplayWorker::setMonitorEnable(Monitor *monitor, const bool enable)
 {
     MonitorInter *inter = m_monitors.value(monitor);
     inter->Enable(enable).waitForFinished();
-    m_displayInter.ApplyChanges().waitForFinished();
-    m_displayInter.Save().waitForFinished();
+    applyChanges();
 }
 
 void DisplayWorker::applyChanges()
 {
-    m_displayInter.ApplyChanges().waitForFinished();
+    if (!m_timer->isActive()) {
+        m_timer->start();
+    }
 }
 
 void DisplayWorker::setColorTemperature(int value)
 {
-    m_displayInter.SetColorTemperature(value);
+    m_displayInter.SetColorTemperature(value).waitForFinished();
 }
 
 void DisplayWorker::SetMethodAdjustCCT(int mode)
@@ -235,11 +243,17 @@ void DisplayWorker::SetMethodAdjustCCT(int mode)
     m_displayInter.SetMethodAdjustCCT(mode);
 }
 
+void DisplayWorker::setCurrentFillMode(Monitor *mon,const QString fillMode)
+{
+    MonitorInter *inter = m_monitors.value(mon);
+    Q_ASSERT(inter);
+    inter->setCurrentFillMode(fillMode);
+}
+
 void DisplayWorker::setMonitorResolution(Monitor *mon, const int mode)
 {
     MonitorInter *inter = m_monitors.value(mon);
     Q_ASSERT(inter);
-
     inter->SetMode(static_cast<uint>(mode)).waitForFinished();
 }
 
@@ -255,9 +269,7 @@ void DisplayWorker::setMonitorPosition(QHash<Monitor *, QPair<int, int>> monitor
         Q_ASSERT(inter);
         inter->SetPosition(static_cast<short>(it.value().first), static_cast<short>(it.value().second)).waitForFinished();
     }
-
-    m_displayInter.ApplyChanges().waitForFinished();
-    m_displayInter.Save().waitForFinished();
+    applyChanges();
 }
 
 void DisplayWorker::setUiScale(const double value)
@@ -348,6 +360,9 @@ void DisplayWorker::monitorAdded(const QString &path)
     connect(inter, &MonitorInter::ModesChanged, mon, &Monitor::setModeList);
     connect(inter, &MonitorInter::RotationsChanged, mon, &Monitor::setRotateList);
     connect(inter, &MonitorInter::EnabledChanged, mon, &Monitor::setMonitorEnable);
+    connect(inter, &MonitorInter::CurrentRotateModeChanged, mon, &Monitor::setCurrentRotateMode);
+    connect(inter, &MonitorInter::AvailableFillModesChanged, mon, &Monitor::setAvailableFillModes);
+    connect(inter, &MonitorInter::CurrentFillModeChanged, mon, &Monitor::setCurrentFillMode);
     connect(&m_displayInter, static_cast<void (DisplayInter::*)(const QString &) const>(&DisplayInter::PrimaryChanged), mon, &Monitor::setPrimary);
     connect(this, &DisplayWorker::requestUpdateModeList, this, [=] {
         mon->setModeList(inter->modes());
@@ -361,6 +376,10 @@ void DisplayWorker::monitorAdded(const QString &path)
     QDBusReply<bool> reply = m_displayDBusInter->call("CanSetBrightness", inter->name());
     mon->setCanBrightness(reply.value());
     mon->setMonitorEnable(inter->enabled());
+    mon->setCurrentRotateMode(inter->currentRotateMode());
+    mon->setMonitorEnable(inter->enabled());
+    mon->setCurrentFillMode(inter->currentFillMode());
+    mon->setAvailableFillModes(inter->availableFillModes());
     mon->setPath(path);
     mon->setX(inter->x());
     mon->setY(inter->y());
@@ -432,9 +451,9 @@ void DisplayWorker::setAmbientLightAdjustBrightness(bool able)
     m_powerInter->setAmbientLightAdjustBrightness(able);
 }
 
-void DisplayWorker::setTouchScreenAssociation(const QString &monitor, const QString &touchscreenSerial)
+void DisplayWorker::setTouchScreenAssociation(const QString &monitor, const QString &touchscreenUUID)
 {
-    m_displayInter.AssociateTouch(monitor, touchscreenSerial);
+    m_displayInter.AssociateTouch(monitor, touchscreenUUID);
 }
 
 void DisplayWorker::setMonitorResolutionBySize(Monitor *mon, const int width, const int height)
