@@ -18,6 +18,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
+#include "modules/authentication/loginoptionsmodule.h"
 #include "modules/accounts/accountsmodule.h"
 #include "modules/bluetooth/bluetoothmodule.h"
 #include "modules/commoninfo/commoninfomodule.h"
@@ -25,7 +26,6 @@
 #include "modules/defapp/defaultappsmodule.h"
 #include "modules/keyboard/keyboardmodule.h"
 #include "modules/power/powermodule.h"
-#include "modules/unionid/unionidmodule.h"
 #include "modules/sound/soundmodule.h"
 #include "modules/update/updatemodule.h"
 #include "modules/mouse/mousemodule.h"
@@ -36,7 +36,6 @@
 #include "modules/sync/syncmodule.h"
 #include "modules/notification/notificationmodule.h"
 #include "modules/systeminfo/systeminfomodule.h"
-#include "modules/network/networkmodule.h"
 #include "modules/defapp/defaultappsmodule.h"
 #include "modules/update/mirrorswidget.h"
 #include "widgets/multiselectlistview.h"
@@ -47,6 +46,7 @@
 #include "dtitlebar.h"
 #include "utils.h"
 #include "interface/moduleinterface.h"
+#include "window/gsettingwatcher.h"
 
 #include <DBackgroundGroup>
 #include <DIconButton>
@@ -67,17 +67,20 @@
 #include <QMouseEvent>
 #include <QResizeEvent>
 #include <QDialog>
+#include <QDesktopWidget>
+#include <QApplication>
 
 using namespace DCC_NAMESPACE;
 using namespace DCC_NAMESPACE::search;
 DTK_USE_NAMESPACE
 #define GSETTINGS_HIDE_MODULE "hide-module"
-#define GSETTINGS_HIDE_VERSIONTYPR "hide-version-type-module"
 
 const QByteArray ControlCenterGSettings = "com.deepin.dde.control-center";
 const QString GSettinsWindowWidth = "window-width";
 const QString GSettinsWindowHeight = "window-height";
 const QString ModuleDirectory = "/usr/lib/dde-control-center/modules";
+const QString ControlCenterIconPath = "/usr/share/icons/bloom/apps/64/preferences-system.svg";
+const QString ControlCenterGroupName = "com.deepin.dde-grand-search.group.dde-control-center-setting";
 
 static int WidgetMinimumWidth = 820;
 static int WidgetMinimumHeight = 634;
@@ -110,11 +113,14 @@ MainWindow::MainWindow(QWidget *parent)
     , m_firstCount(-1)
     , m_widgetName("")
     , m_backwardBtn(nullptr)
+    , m_lastSize(WidgetMinimumWidth, WidgetMinimumHeight)
+    , m_primaryScreen(nullptr)
 {
     //Initialize view and layout structure
     DMainWindow::installEventFilter(this);
 
     QWidget *content = new QWidget(this);
+    content->setAccessibleName("contentwindow");
     content->setObjectName("contentwindow");
     m_contentLayout = new QHBoxLayout(content);
     m_contentLayout->setContentsMargins(0, 0, 0, 0);
@@ -133,12 +139,6 @@ MainWindow::MainWindow(QWidget *parent)
     m_navView->setEditTriggers(QListView::NoEditTriggers);
     m_navView->setResizeMode(QListView::Adjust);
     m_navView->setAutoScroll(true);
-
-    QScroller *scroller = QScroller::scroller(m_navView->viewport());
-    QScrollerProperties sp;
-    sp.setScrollMetric(QScrollerProperties::VerticalOvershootPolicy, QScrollerProperties::OvershootAlwaysOff);
-    scroller->setScrollerProperties(sp);
-
     m_contentLayout->addWidget(m_navView, 1);
     m_contentLayout->addWidget(m_rightView, 5);
 
@@ -158,6 +158,7 @@ MainWindow::MainWindow(QWidget *parent)
     m_searchWidget->setMinimumSize(350, 36);
     m_searchWidget->setAccessibleName("SearchModule");
     m_searchWidget->lineEdit()->setAccessibleName("SearchModuleLineEdit");
+    GSettingWatcher::instance()->bind("mainwindowSearchEdit", m_searchWidget);
 
     DTitlebar *titlebar = this->titlebar();
     auto widhetlist = titlebar->children();
@@ -183,17 +184,7 @@ MainWindow::MainWindow(QWidget *parent)
     auto action = new QAction(tr("Help"));
     menu->addAction(action);
     connect(action, &QAction::triggered, this, [ = ] {
-        QString helpTitle = m_moduleName;
-        if (helpTitle.isEmpty()) {
-            helpTitle = "controlcenter";
-        }
-        const QString dmanInterface = "com.deepin.Manual.Open";
-        QDBusInterface *inter = new QDBusInterface(dmanInterface,
-                                                   "/com/deepin/Manual/Open",
-                                                   dmanInterface,
-                                                   QDBusConnection::sessionBus());
-        inter->call("OpenTitle", "dde", helpTitle);
-        inter->deleteLater();
+        openManual();
     });
 
     m_backwardBtn = new DIconButton(this);
@@ -201,6 +192,7 @@ MainWindow::MainWindow(QWidget *parent)
     m_backwardBtn->setEnabled(false);
     m_backwardBtn->setIcon(QStyle::SP_ArrowBack);
     QWidget *backWidget = new QWidget();
+    backWidget->setAccessibleName("backWidget");
     QHBoxLayout *btnLayout = new QHBoxLayout();
     btnLayout->addSpacing(5);
     btnLayout->addWidget(m_backwardBtn);
@@ -219,7 +211,6 @@ MainWindow::MainWindow(QWidget *parent)
         resetNavList(m_contentStack.isEmpty());
     });
     updateViewBackground();
-    updateWinsize();
 }
 
 MainWindow::~MainWindow()
@@ -249,6 +240,7 @@ void MainWindow::onBack()
 void MainWindow::resetTabOrder()
 {
     QWidget *pre = m_navView;
+    pre->setAccessibleName("mainwindow_pre");
     pre->setFocusPolicy(Qt::TabFocus);
     for (int i = 0; i < m_contentStack.size(); ++i) {
         auto tw = m_contentStack.at(i).second;
@@ -304,17 +296,26 @@ void MainWindow::findFocusChild(QLayout *l, QWidget *&pre)
     }
 }
 
+void MainWindow::setPrimaryScreen(QScreen *screen)
+{
+    if(m_primaryScreen == screen)
+        return;
+
+    m_primaryScreen = screen;
+    updateWinsize();
+    connect(m_primaryScreen, &QScreen::geometryChanged, this, &MainWindow::updateWinsize);
+}
+
 void MainWindow::initAllModule(const QString &m)
 {
     if (m_bInit)
         return;
 
     m_bInit = true;
+    using namespace authentication;
     using namespace sync;
-    using namespace unionid;
     using namespace datetime;
     using namespace defapp;
-    using namespace network;
     using namespace display;
     using namespace touchscreen;
     using namespace accounts;
@@ -330,21 +331,15 @@ void MainWindow::initAllModule(const QString &m)
     using namespace commoninfo;
     using namespace notification;
 
-    QString idType = "Union ID";
-    if (DSysInfo::isCommunityEdition())
-        idType = "Deepin ID";
-
     m_modules = {
+        { new LoginOptionsModule(this), tr("Biometric Authentication")},
         { new AccountsModule(this), tr("Accounts")},
-        // 原union ID 暂时隐藏
-        // { new UnionidModule(this), "Union ID"},
         //~ contents_path /cloudsync/Cloud Sync
         { new SyncModule(this), DSysInfo::isCommunityEdition() ? "Deepin ID" : "Union ID"},
         { new DisplayModule(this), tr("Display")},
         { new TouchscreenModule(this), tr("Touch Screen")},
         { new DefaultAppsModule(this), tr("Default Applications")},
         { new PersonalizationModule(this), tr("Personalization")},
-        { new NetworkModule(this), tr("Network")},
         { new NotificationModule(this), tr("Notification")},
         { new SoundModule(this), tr("Sound")},
         { new BluetoothModule(this), tr("Bluetooth")},
@@ -359,7 +354,7 @@ void MainWindow::initAllModule(const QString &m)
     };
 
     //读取加载一级菜单的插件
-    if (InsertPlugin::instance(this, this)->needPushPlugin("mainwindow"))
+    if (InsertPlugin::instance(this, this)->updatePluginInfo("mainwindow"))
         InsertPlugin::instance()->pushPlugin(m_modules);
 
     //通过gsetting设置某模块是否显示,默认都显示
@@ -371,18 +366,6 @@ void MainWindow::initAllModule(const QString &m)
         }
         updateModuleVisible();
     });
-    updateModuleVisible();
-
-    //通过gsetting获取版本类型，设置某模块是否显示
-    if (QGSettings::isSchemaInstalled("com.deepin.dde.control-versiontype")) {
-        m_versionType  = new QGSettings("com.deepin.dde.control-versiontype", QByteArray(), this);
-        auto versionTypeList =  m_versionType->get(GSETTINGS_HIDE_VERSIONTYPR).toStringList();
-        for (auto i : m_modules) {
-            if (versionTypeList.contains((i.first->name()))) {
-                setModuleVisible(i.first, false);
-            }
-        }
-    }
 
     bool isIcon = m_contentStack.empty();
 
@@ -427,9 +410,7 @@ void MainWindow::initAllModule(const QString &m)
     resetNavList(isIcon);
 
     modulePreInitialize(m);
-    //设置 触控板，指点杆 是否存在
-    m_searchWidget->setRemoveableDeviceStatus(tr("Touchpad"), getRemoveableDeviceStatus(tr("Touchpad")));
-    m_searchWidget->setRemoveableDeviceStatus(tr("TrackPoint"), getRemoveableDeviceStatus(tr("TrackPoint")));
+    updateModuleVisible();
 
     QElapsedTimer et;
     et.start();
@@ -438,13 +419,29 @@ void MainWindow::initAllModule(const QString &m)
     qDebug() << QString("load search info with %1ms").arg(et.elapsed());
 }
 
-void MainWindow::updateWinsize()
+void MainWindow::updateWinsize(QRect rect)
 {
-    int w = QGuiApplication::primaryScreen()->geometry().width();
-    int h = QGuiApplication::primaryScreen()->geometry().height();
+    if (!qApp->screens().contains(m_primaryScreen))
+        return;
+
+    int w = m_primaryScreen->geometry().width();
+    int h = m_primaryScreen->geometry().height();
+    if (rect.width() && rect.height()) {
+        w = rect.width();
+        h = rect.height();
+    }
     WidgetMinimumWidth = qMin(w, 820);
     WidgetMinimumHeight = qMin(h, 634);
+
     setMinimumSize(QSize(WidgetMinimumWidth, WidgetMinimumHeight));
+
+    if (width() > WidgetMinimumWidth)
+        this->setGeometry(x(), y(), WidgetMinimumWidth, height());
+    if (height() > WidgetMinimumHeight)
+        this->setGeometry(x(), y(), width(), WidgetMinimumHeight);
+
+    move(QPoint(m_primaryScreen->geometry().left() + (m_primaryScreen->geometry().width() - this->geometry().width()) / 2,
+                m_primaryScreen->geometry().top() + (m_primaryScreen->geometry().height() - this->geometry().height()) / 2));
 }
 
 void MainWindow::updateModuleVisible()
@@ -452,9 +449,11 @@ void MainWindow::updateModuleVisible()
     m_hideModuleNames = m_moduleSettings->get(GSETTINGS_HIDE_MODULE).toStringList();
     for (auto i : m_modules) {
         if (m_hideModuleNames.contains((i.first->name()))) {
-            setModuleVisible(i.first, false);
-        } else {
-            setModuleVisible(i.first, true);
+            setModuleVisible(i.second, false);
+        } else if (i.first->deviceUnavailabel()) {
+            setModuleVisible(i.second, false);
+        } else if (i.first->isAvailable()) {
+            setModuleVisible(i.second, true);
         }
     }
 }
@@ -468,14 +467,18 @@ void MainWindow::modulePreInitialize(const QString &m)
         qDebug() << QString("initialize %1 module using time: %2ms")
                  .arg(it->first->name())
                  .arg(et.elapsed());
-
-        setModuleVisible(it->first, it->first->isAvailable());
+        if (it->first->isAvailable()) {
+            // 模块有效时先初始化模块和搜索数据
+            InsertPlugin::instance()->preInitialize(it->first->name());
+        }
     }
 }
 
 void MainWindow::popWidget()
 {
     if (m_topWidget) {
+        if(0 < m_contentStack.count())
+            m_lastPushWidget = m_contentStack.last().second;
         m_topWidget->deleteLater();
         m_topWidget = nullptr;
         return;
@@ -527,10 +530,20 @@ void MainWindow::popWidget(ModuleInterface *const inter)
 void MainWindow::showModulePage(const QString &module, const QString &page, bool animation)
 {
     Q_UNUSED(animation)
+
+    if (module == m_moduleName && page.isEmpty()) { //当前模块且未指定页面，直接返回
+        //Note: 在关闭窗口特效的情况下，控制中心最小化之后，调用show()，无法显示出来【开了窗口特效则无此问题】
+        setWindowState(windowState() &~ Qt::WindowMinimized);
+        show();
+        activateWindow();
+        return;
+    }
+
     // FIXME: 通过dbus触发切换page菜单界面时，应先检测当前page界面是否存在模态对话框在上层显示，
     // 若存在则先将其所有对话框强制关闭，再执行切换page界面显示
-    if (m_lastPushWidget && m_lastPushWidget->isVisible()) {
-        QList<QDialog *> dialogList = m_lastPushWidget->findChildren<QDialog *>();
+    QWidget *lastPushWidget = qobject_cast<QWidget*>(m_lastPushWidget);//判断指针是否失效
+    if (lastPushWidget && lastPushWidget->isVisible()) {
+        QList<QDialog *> dialogList = lastPushWidget->findChildren<QDialog *>();
         for (QDialog *dlg : dialogList) {
             if (dlg && dlg->isVisible()) {
                 dlg->done(QDialog::Rejected);
@@ -590,8 +603,11 @@ void MainWindow::showModulePage(const QString &module, const QString &page, bool
     onEnterSearchWidget(module, page);
     // Note: 当直接进入模块界面(二级界面)，先将模块界面显示出来，在加载首界面
     QTimer::singleShot(0, this, [ = ] {
-        if (isMinimized() || !isVisible())
-            showNormal();
+        if (isMinimized() || !isVisible()) {
+            //Note: 在关闭窗口特效的情况下，控制中心最小化之后，调用show()，无法显示出来【开了窗口特效则无此问题】
+            setWindowState(windowState() &~ Qt::WindowMinimized);
+            show();
+        }
 
         activateWindow();
     });
@@ -652,6 +668,24 @@ void MainWindow::toggle()
     activateWindow();
 }
 
+void MainWindow::openManual()
+{
+    QString helpTitle = m_moduleName;
+    if (helpTitle.isEmpty()) {
+        helpTitle = "controlcenter";
+    }
+    const QString dmanInterface = "com.deepin.Manual.Open";
+    QDBusInterface interface(dmanInterface,
+                             "/com/deepin/Manual/Open",
+                             dmanInterface,
+                             QDBusConnection::sessionBus());
+
+    QDBusMessage reply = interface.call("OpenTitle", "dde", helpTitle);
+    if (reply.type() == QDBusMessage::ErrorMessage) {
+        qDebug() << "reply.type() = " << reply.type();
+    }
+}
+
 void MainWindow::keyPressEvent(QKeyEvent *event)
 {
     switch (event->key()) {
@@ -661,17 +695,7 @@ void MainWindow::keyPressEvent(QKeyEvent *event)
         }
         break;
     case Qt::Key_F1: {
-        QString helpTitle = m_moduleName;
-        if (helpTitle.isEmpty()) {
-            helpTitle = "controlcenter";
-        }
-        const QString dmanInterface = "com.deepin.Manual.Open";
-        QDBusInterface *inter = new QDBusInterface(dmanInterface,
-                                                   "/com/deepin/Manual/Open",
-                                                   dmanInterface,
-                                                   QDBusConnection::sessionBus());
-        inter->call("OpenTitle", "dde", helpTitle);
-        inter->deleteLater();
+        openManual();
         break;
     }
     default:
@@ -699,11 +723,24 @@ bool MainWindow::eventFilter(QObject *watched, QEvent *event)
         }
     }
 
+    if (event->type() == QEvent::Shortcut) {
+        auto ke = static_cast<QShortcutEvent *>(event);
+        if (ke->key() == Qt::Key_F1) {
+            openManual();
+            return true;
+        }
+    }
+
     return  DMainWindow::eventFilter(watched, event);
 }
 
 void MainWindow::resizeEvent(QResizeEvent *event)
 {
+    if (m_needRememberLastSize && event->oldSize() != event->size()) {
+        m_lastSize = event->oldSize();
+    }
+    m_needRememberLastSize = true;
+
     DMainWindow::resizeEvent(event);
 
     auto dstWidth = event->size().width();
@@ -752,6 +789,9 @@ void MainWindow::resetNavList(bool isIconMode)
         return;
 
     if (isIconMode) {
+        if (m_lastPushWidget)
+            m_lastPushWidget = nullptr;
+
         //Only remain 1 level page : back to top page
         m_navView->setViewportMargins(QMargins(0, 0, 0, 0));
         m_navView->setViewMode(QListView::IconMode);
@@ -783,6 +823,7 @@ void MainWindow::resetNavList(bool isIconMode)
         DStyle::setFrameRadius(m_navView, 18);
         m_rightView->hide();
         m_backwardBtn->setEnabled(false);
+        m_moduleName.clear();
     } else {
         //The second page will Covered with fill blank areas
         m_navView->setViewportMargins(QMargins(10, 10, 10, 10));
@@ -820,37 +861,12 @@ void MainWindow::resetNavList(bool isIconMode)
 
 void MainWindow::onEnterSearchWidget(QString moduleName, QString widget)
 {
-    QStringList widgetPages = widget.split(",");
-    QString widgetFirst = widgetPages[0];
-    qDebug() << Q_FUNC_INFO << " moduleName : " << moduleName << " , widget :" << widgetFirst;
-
-    if (!m_contentStack.isEmpty()
-            && (m_contentStack.top().first->name() == moduleName)
-            && (m_widgetName == widgetFirst)) {
-        qDebug() << Q_FUNC_INFO << " Search widget is current display widget.";
-        // load wireless detail pages.
-        if ((moduleName == "network") && (widgetPages.size() > 1)) {
-            auto res = std::find_if(m_modules.begin(), m_modules.end(), [ = ](const QPair<ModuleInterface *, QString> &data)->bool{
-                return data.first->name() == moduleName;
-            });
-
-            if (res != m_modules.end()) {
-                (*res).first->load(widget);
-                return;
-            }
-        }
-        if ((moduleName == "keyboard") && (widgetPages.size() >= 1)) {
-            auto res = std::find_if(m_modules.begin(), m_modules.end(), [ = ](const QPair<ModuleInterface *, QString> &data)->bool{
-                return data.first->name() == moduleName;
-            });
-
-            if (res != m_modules.end()) {
-                (*res).first->load(widget);
-                return;
-            }
-        }
-        return;
-    }
+    QString widgetFirst = widget;
+    if (widget.contains(','))
+        widgetFirst = widget.split(',').first();
+    if (widget.contains('/'))
+        widgetFirst = widget.split('/').first();
+    qDebug() << Q_FUNC_INFO << " moduleName:" << moduleName << ", widget:" << widget << ", widgetFirst:" << widgetFirst;
 
     for (int firstCount = 0; firstCount < m_modules.count(); firstCount++) {
         //Compare moduleName and m_modules.second(module name)
@@ -870,8 +886,14 @@ void MainWindow::onEnterSearchWidget(QString moduleName, QString widget)
             m_widgetName = widgetFirst;
 
             //notify related module load widget
-//            QTimer::singleShot(0, this, [ = ] { //avoid default and load sequence in time
             auto errCode = m_modules[m_firstCount].first->load(widget);
+            // 添加插件load调用方法
+            if (InsertPlugin::instance()->updatePluginInfo(moduleName)) {
+                auto *plugin = InsertPlugin::instance()->pluginInterface(widgetFirst);
+                if (plugin) {
+                    errCode = plugin->load(widget);
+                }
+            }
             if (!errCode || m_widgetName == "") {
                 return;
             }
@@ -883,7 +905,6 @@ void MainWindow::onEnterSearchWidget(QString moduleName, QString widget)
             if (calledFromDBus()) {
                 sendErrorReply(QDBusError::InvalidArgs, errStr);
             }
-//            });
             break;
         }
     }
@@ -904,70 +925,98 @@ void MainWindow::changeEvent(QEvent *event)
 
 void MainWindow::setModuleVisible(ModuleInterface *const inter, const bool visible)
 {
+    auto find_it = std::find_if(m_modules.cbegin(),
+                                m_modules.cend(),
+    [ inter ](const QPair<ModuleInterface *, QString> &pair) {
+        return pair.first == inter;
+    });
+    if (find_it == m_modules.cend()) {
+        qDebug() << Q_FUNC_INFO << "Not found module:" << inter->name();
+        return;
+    }
     bool bFinalVisible = visible;
     if (bFinalVisible && m_hideModuleNames.contains(inter->name())) {
         bFinalVisible = false;
     }
-    inter->setAvailable(bFinalVisible);
 
+    m_navView->setRowHidden(find_it - m_modules.cbegin(), !bFinalVisible);
+    Q_EMIT moduleVisibleChanged(find_it->first->name(), bFinalVisible);
+
+    qDebug() << "[SearchWidget] find_it->first->name() : " << find_it->first->name() << bFinalVisible;
+    if (!bFinalVisible && m_contentStack.count() > 0  && m_contentStack.at(0).first->name() == inter->name()) {
+        popAllWidgets();
+        resetNavList(m_contentStack.empty());
+    }
+
+    updateSearchData(find_it->second);
+
+    if (!m_searchWidget) {
+        return;
+    }
+
+    m_searchWidget->setModuleVisible(find_it->second, bFinalVisible);
+}
+
+void MainWindow::setModuleVisible(const QString &module, bool visible)
+{
     auto find_it = std::find_if(m_modules.cbegin(),
                                 m_modules.cend(),
-    [ = ](const QPair<ModuleInterface *, QString> &pair) {
-        return pair.first == inter;
+    [ &module ](const QPair<ModuleInterface *, QString> &pair) {
+        return pair.second == module;
     });
-
-    if (find_it != m_modules.cend()) {
-        m_navView->setRowHidden(find_it - m_modules.cbegin(), !bFinalVisible);
-        Q_EMIT moduleVisibleChanged(find_it->first->name(), bFinalVisible);
-
-        qDebug() << "[SearchWidget] find_it->first->name() : " << find_it->first->name() << bFinalVisible;
-        if ("bluetooth" == find_it->first->name()) {
-            if (bFinalVisible) {
-                m_searchWidget->removeUnExsitData(tr("Bluetooth"));
-            } else {
-                m_searchWidget->addUnExsitData(tr("Bluetooth"));
-
-                //当前处于＂蓝牙＂页面才会回到主页面
-                if (m_contentStack.count() > 0 && m_contentStack.at(0).first->name() == "bluetooth") {
-                    popAllWidgets();
-                    resetNavList(m_contentStack.empty());
-                }
-            }
-        } else if ("wacom" == find_it->first->name()) {
-            if (bFinalVisible) {
-                m_searchWidget->removeUnExsitData(tr("Drawing Tablet"));
-            } else {
-                m_searchWidget->addUnExsitData(tr("Drawing Tablet"));
-
-                //当前处于＂数位板＂页面才会回到主页面
-                if (m_contentStack.count() > 0 && m_contentStack.at(0).first->name() == "wacom") {
-                    popAllWidgets();
-                    resetNavList(m_contentStack.empty());
-                }
-            }
-        }  else if ("cloudsync" == find_it->first->name()) {
-            if (bFinalVisible) {
-                m_searchWidget->removeUnExsitData(tr("Cloud Sync"));
-            } else {
-                m_searchWidget->addUnExsitData(tr("Cloud Sync"));
-            }
-        } else if ("commoninfo" == find_it->first->name()) {
-            if (bFinalVisible) {
-                m_searchWidget->removeUnExsitData(tr("General Settings"));
-            } else {
-                m_searchWidget->addUnExsitData(tr("General Settings"));
-            }
-        } else if ("update" == find_it->first->name()) {
-            m_updateVisibale = bFinalVisible;
-            if (bFinalVisible) {
-                m_searchWidget->removeUnExsitData(tr("Updates"));
-            } else {
-                m_searchWidget->addUnExsitData(tr("Updates"));
-            }
-        }
-    } else {
-        qDebug() << Q_FUNC_INFO << "Not found module!";
+    if (find_it == m_modules.cend()) {
+        qDebug() << Q_FUNC_INFO << "Not found module:" << module;
+        return;
     }
+    const auto& inter = find_it->first;
+    bool bFinalVisible = visible;
+    if (bFinalVisible && m_hideModuleNames.contains(inter->name())) {
+        bFinalVisible = false;
+    }
+
+    m_navView->setRowHidden(find_it - m_modules.cbegin(), !bFinalVisible);
+    Q_EMIT moduleVisibleChanged(find_it->first->name(), bFinalVisible);
+
+    qDebug() << "[SearchWidget] find_it->first->name() : " << find_it->first->name() << bFinalVisible;
+    if (!bFinalVisible && m_contentStack.count() > 0  && m_contentStack.at(0).first->name() == inter->name()) {
+        popAllWidgets();
+        resetNavList(m_contentStack.empty());
+    }
+
+    updateSearchData(find_it->second);
+
+    if (!m_searchWidget) {
+        return;
+    }
+
+    m_searchWidget->setModuleVisible(module, bFinalVisible);
+}
+
+void MainWindow::setWidgetVisible(const QString &module, const QString &widget, bool visible)
+{
+    if (!m_searchWidget) {
+        return;
+    }
+
+    m_searchWidget->setWidgetVisible(module, widget, visible);
+}
+
+void MainWindow::setDetailVisible(const QString &module, const QString &widget, const QString &detail, bool visible)
+{
+    if (!m_searchWidget) {
+        return;
+    }
+
+    m_searchWidget->setDetailVisible(module, widget, detail, visible);
+}
+
+void MainWindow::updateSearchData(const QString &module)
+{
+    if (!m_searchWidget) {
+        return;
+    }
+
+    m_searchWidget->updateSearchdata(module);
 }
 
 void MainWindow::pushWidget(ModuleInterface *const inter, QWidget *const w, PushType type)
@@ -1071,6 +1120,9 @@ void MainWindow::pushNormalWidget(ModuleInterface *const inter, QWidget *const w
     if (m_contentStack.size() == 2) {
         m_contentStack.at(0).second->setMinimumWidth(second_widget_min_width);
         m_contentStack.at(1).second->setMinimumWidth(third_widget_min_width);
+
+        //解决插件二级菜单右侧两角为圆角的问题[正常情况圆角应该在三级菜单的右侧两角和二级菜单的左侧两角]
+        m_contentStack.at(1).second->show();
     }
 
     resetNavList(m_contentStack.empty());
@@ -1149,7 +1201,8 @@ void MainWindow::onFirstItemClick(const QModelIndex &index)
 {
     ModuleInterface *inter = m_modules[index.row()].first;
 
-    if (!m_contentStack.isEmpty() && m_contentStack.last().first == inter) {
+    if (!m_contentStack.isEmpty() && m_contentStack.first().first == inter) {
+        m_navView->setFocus();
         return;
     }
 
@@ -1230,31 +1283,115 @@ void FourthColWidget::paintEvent(QPaintEvent *event)
     painter.drawRect(rt);
 }
 
+// 该函数已废弃
 void MainWindow::setRemoveableDeviceStatus(QString type, bool state)
 {
-    //state:true,list里面不存在，则加入到list
-    //state:false,list里面存在，则从list移除
-    if (state) {
-        if (!m_removeableDeviceList.contains(type)) {
-            m_removeableDeviceList.append(type);
-        }
-    } else {
-        if (m_removeableDeviceList.contains(type)) {
-            m_removeableDeviceList.removeOne(type);
-        }
-    }
-
-    //通知设备“添加/移除"状态
-    if (m_searchWidget)
-        m_searchWidget->setRemoveableDeviceStatus(type, state);
+    Q_UNUSED(type);
+    Q_UNUSED(state);
 }
 
+// 该函数已废弃
 bool MainWindow::getRemoveableDeviceStatus(QString type) const
 {
-    return m_removeableDeviceList.contains(type);
+    return false;
 }
 
-void MainWindow::setSearchPath(ModuleInterface * const inter) const
+void MainWindow::setSearchPath(ModuleInterface *const inter) const
 {
     m_searchWidget->addModulesName(inter->name(), inter->displayName(), inter->icon(), inter->translationPath());
 }
+
+QString MainWindow::GrandSearchSearch(const QString json)
+{
+    //解析输入的json值
+    QJsonDocument jsonDocument = QJsonDocument::fromJson(json.toLocal8Bit().data());
+    if(!jsonDocument.isNull()) {
+        QJsonObject jsonObject = jsonDocument.object();
+        m_lstGrandSearchTasks.append(jsonObject);
+
+        //处理搜索任务, 返回搜索结果
+        QList<QString> lstMsg = m_searchWidget->searchResults(jsonObject.value("cont").toString());
+
+        for(auto msg : lstMsg) {
+            qDebug() << "name:" << msg;
+        }
+
+        QJsonObject jsonResults;
+        QJsonArray items;
+        for (int i = 0; i < lstMsg.size(); i++) {
+            QJsonObject jsonObj;
+            jsonObj.insert("item", lstMsg[i]);
+            jsonObj.insert("name", lstMsg[i]);
+            jsonObj.insert("icon", ControlCenterIconPath);
+            jsonObj.insert("type", "application/x-dde-control-center-xx");
+
+            items.insert(i, jsonObj);
+        }
+
+        QJsonObject objCont;
+        objCont.insert("group",ControlCenterGroupName);
+        objCont.insert("items", items);
+
+        QJsonArray arrConts;
+        arrConts.insert(0, objCont);
+
+        jsonResults.insert("ver", jsonObject.value("ver"));
+        jsonResults.insert("mID", jsonObject.value("mID"));
+        jsonResults.insert("cont", arrConts);
+
+        QJsonDocument document;
+        document.setObject(jsonResults);
+        m_lstGrandSearchTasks.removeOne(jsonObject);
+
+        return document.toJson(QJsonDocument::Compact);
+   }
+
+    return QString();
+}
+
+bool MainWindow::GrandSearchStop(const QString json)
+{
+    Q_UNUSED(json)
+    return true;
+}
+
+bool MainWindow::GrandSearchAction(const QString json)
+{
+    QString searchName;
+    QJsonDocument jsonDocument = QJsonDocument::fromJson(json.toLocal8Bit().data());
+    if(!jsonDocument.isNull()) {
+        QJsonObject jsonObject = jsonDocument.object();
+        if (jsonObject.value("action") == "openitem") {
+            //打开item的操作
+            searchName = jsonObject.value("item").toString();
+        }
+    }
+
+    show();
+    activateWindow();
+    m_searchWidget->jumpContentPathWidget(searchName);
+    return true;
+}
+
+void MainWindow::addChildPageTrans(const QString &menu, const QString &tran)
+{
+    if (!m_searchWidget) {
+        return;
+    }
+
+    m_searchWidget->addChildPageTrans(menu, tran);
+}
+
+QString MainWindow::moduleDisplayName(const QString &module) const
+{
+    auto find_it = std::find_if(m_modules.cbegin(),
+                                m_modules.cend(),
+    [ module ](const QPair<ModuleInterface *, QString> &pair) {
+        return pair.first->name() == module;
+    });
+    if (find_it == m_modules.cend()) {
+        qDebug() << Q_FUNC_INFO << "Not found module:" << module;
+        return QString();
+    }
+    return find_it->second;
+}
