@@ -21,7 +21,6 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-#include "navigation/navmodel.h"
 #include "interface/frameproxyinterface.h"
 
 #include <DMainWindow>
@@ -88,11 +87,21 @@ public:
     void popWidget(ModuleInterface *const inter) override;
     void pushWidget(ModuleInterface *const inter, QWidget *const w, PushType type = Normal) override;
     void setModuleVisible(ModuleInterface *const inter, const bool visible) override;
+    void setModuleVisible(const QString &module, bool visible) override;
+    void setWidgetVisible(const QString &module, const QString &widget, bool visible) override;
+    void setDetailVisible(const QString &module, const QString &widget, const QString &detail, bool visible) override;
+    void updateSearchData(const QString &module) override;
     void showModulePage(const QString &module, const QString &page, bool animation) override;
     void setModuleSubscriptVisible(const QString &module, bool bIsDisplay) override;
     void setRemoveableDeviceStatus(QString type, bool state) override;
     bool getRemoveableDeviceStatus(QString type) const override;
     void setSearchPath(ModuleInterface *const inter) const override;
+    void addChildPageTrans(const QString &menu, const QString &tran) override;
+    virtual QString moduleDisplayName(const QString &module) const override;
+
+    QString GrandSearchSearch(const QString json);
+    bool GrandSearchStop(const QString json);
+    bool GrandSearchAction(const QString json);
 
 public:
     bool isModuleAvailable(const QString &m);
@@ -100,7 +109,10 @@ public:
     void popWidget();
     void initAllModule(const QString &m = "");
     inline QStack<QPair<ModuleInterface *, QWidget *>> getcontentStack() {return m_contentStack;}
-    void updateWinsize();
+    inline QSize getLastSize() const { return m_lastSize; }
+    inline void setNeedRememberLastSize(bool needRememberLastSize)  { m_needRememberLastSize = needRememberLastSize;}
+    void setPrimaryScreen(QScreen *screen);
+    inline QScreen *primaryScreen() const { return m_primaryScreen; }
 
 Q_SIGNALS:
     void moduleVisibleChanged(const QString &module, bool visible);
@@ -114,6 +126,10 @@ private Q_SLOTS:
     void resetTabOrder();
     void findFocusChild(QWidget *w, QWidget *&pre);
     void findFocusChild(QLayout *l, QWidget *&pre);
+    void openManual();
+
+public Q_SLOTS:
+    void updateWinsize(QRect rect = QRect(0,0,0,0));
 
 protected:
     void resizeEvent(QResizeEvent *event) override;
@@ -164,6 +180,12 @@ private:
     QStringList m_hideModuleNames;
     bool m_updateVisibale = true;
     QWidget *m_lastPushWidget{nullptr};     //用于记录最后push进来的widget控件
+    QSize m_lastSize;
+    bool m_needRememberLastSize = true;     //用于判断是否需要上次resize的窗口大小
+
+    //全局搜索
+    QList<QJsonObject> m_lstGrandSearchTasks;
+    QScreen *m_primaryScreen;
 };
 }
 
