@@ -20,7 +20,6 @@
  */
 
 #include "accountsdetailwidget.h"
-#include "accountfingeitem.h"
 #include "groupitem.h"
 #include "window/utils.h"
 #include "modules/accounts/usermodel.h"
@@ -37,6 +36,7 @@
 #include <DTipLabel>
 #include <DDesktopServices>
 #include <DLabel>
+#include <DSpinBox>
 
 #include <QStackedWidget>
 #include <QVBoxLayout>
@@ -52,14 +52,49 @@
 #include <QByteArray>
 #include <QPointer>
 
+#include <grp.h>
+
 DWIDGET_USE_NAMESPACE
 using namespace dcc::accounts;
 using namespace dcc::widgets;
 using namespace DCC_NAMESPACE::accounts;
 
-AccountsDetailWidget::AccountsDetailWidget(User *user, QWidget *parent)
+#define MAXVALUE 99999
+#define GSETTINGS_EFFECTIVE_DAY_VISIBLE "effectiveDayVisible"
+
+AccountSpinBox::AccountSpinBox(QWidget *parent)
+    :DSpinBox(parent)
+{
+}
+
+QString AccountSpinBox::textFromValue(int val) const
+{
+    if (val >= MAXVALUE && !lineEdit()->hasFocus()) {
+        return tr("Always");
+    }
+    return QString::number(val);
+}
+
+void AccountSpinBox::focusInEvent(QFocusEvent *event)
+{
+    if (lineEdit()->text() == tr("Always")) {
+        lineEdit()->setText(QString::number(MAXVALUE));
+    }
+    return DSpinBox::focusInEvent(event);
+};
+
+void AccountSpinBox::focusOutEvent(QFocusEvent *event)
+{
+    if (lineEdit()->text().isEmpty()) {
+        editingFinished();
+    }
+    return DSpinBox::focusOutEvent(event);
+}
+
+AccountsDetailWidget::AccountsDetailWidget(User *user, UserModel *model, QWidget *parent)
     : QWidget(parent)
     , m_curUser(user)
+    , m_userModel(model)
     , m_groupListView(nullptr)
     , m_groupItemModel(nullptr)
     , m_avatarLayout(new QHBoxLayout)
@@ -67,6 +102,8 @@ AccountsDetailWidget::AccountsDetailWidget(User *user, QWidget *parent)
     , m_deleteAccount(new DWarningButton)
     , m_modifyPassword(new QPushButton)
     , m_gsettings(new QGSettings("com.deepin.dde.control-center", QByteArray(), this))
+    , m_scrollArea(new QScrollArea)
+    , m_curLoginUser(nullptr)
 {
     m_isServerSystem = IsServerSystem;
     //整体布局
@@ -76,31 +113,34 @@ AccountsDetailWidget::AccountsDetailWidget(User *user, QWidget *parent)
     setLayout(mainContentLayout);
     setFocusPolicy(Qt::FocusPolicy::ClickFocus);
 
-    QScrollArea *scrollArea = new QScrollArea;
-    scrollArea->setWidgetResizable(true);
-    scrollArea->setFrameStyle(QFrame::NoFrame);
-    scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
-    scrollArea->setContentsMargins(0, 0, 0, 0);
+    m_scrollArea->setAccessibleName("scrollArea");
+    m_scrollArea->setWidgetResizable(true);
+    m_scrollArea->setFrameStyle(QFrame::NoFrame);
+    m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    m_scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+    m_scrollArea->setContentsMargins(0, 0, 0, 0);
+    m_scrollArea->setBackgroundRole(QPalette::Base);
 
     QWidget *widget = new QWidget;
+    widget->setAccessibleName("scrollAreaWidget");
     widget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     widget->setContentsMargins(0, 0, 0, 0);
+    widget->setMinimumWidth(330);   //设置滑轮区域最小宽度,避免整体窗口最小的时候,fullnamelable太长导致出现滑轮
 
-    mainContentLayout->addWidget(scrollArea);
+    mainContentLayout->addWidget(m_scrollArea);
     auto contentLayout = new QVBoxLayout();
     contentLayout->setAlignment(Qt::AlignTop | Qt::AlignHCenter);
     contentLayout->setSpacing(0);
     contentLayout->setContentsMargins(0, 0, 0, 0);
     widget->setLayout(contentLayout);
-    scrollArea->setWidget(widget);
+    m_scrollArea->setWidget(widget);
 
     /* 设置账户详情列表支持触屏滑动，不使用TouchGesture的原因，TouchGesture qt内部存在bug。1、滚动区滑动过程中，主窗口也跟随move；
      * 2、滑动回弹过程中，点击头像，窗口出现错位*/
-    QScroller::grabGesture(scrollArea->viewport(), QScroller::LeftMouseButtonGesture);
-    QScroller *scroller = QScroller::scroller(scrollArea->viewport());
+    QScroller::grabGesture(m_scrollArea->viewport(), QScroller::LeftMouseButtonGesture);
+    QScroller *scroller = QScroller::scroller(m_scrollArea->viewport());
     QScrollerProperties sp;
-    sp.setScrollMetric(QScrollerProperties::VerticalOvershootPolicy, QScrollerProperties::OvershootAlwaysOff);
+    sp.setScrollMetric(QScrollerProperties::VerticalOvershootPolicy, QScrollerProperties::OvershootWhenScrollable);
     scroller->setScrollerProperties(sp);
 
     initUserInfo(contentLayout);
@@ -109,6 +149,8 @@ AccountsDetailWidget::AccountsDetailWidget(User *user, QWidget *parent)
     if (m_isServerSystem) {
         initGroups(contentLayout);
     }
+
+    setAccountModel(model);
 }
 
 AccountsDetailWidget::~AccountsDetailWidget()
@@ -116,20 +158,6 @@ AccountsDetailWidget::~AccountsDetailWidget()
     GSettingWatcher::instance()->erase("accountUserFullnamebtn", m_fullNameBtn);
 }
 
-void AccountsDetailWidget::setFingerModel(FingerModel *model)
-{
-    m_model = model;
-    m_fingerWidget->setFingerModel(model);
-    connect(model, &FingerModel::vaildChanged, this, [this](const bool isVaild) {
-        if (m_curUser->isCurrentUser()) {
-            m_fingerWidget->setVisible(!IsServerSystem && isVaild);
-        }
-    });
-    if (m_curUser->isCurrentUser()) {
-        m_fingerWidget->setVisible(!IsServerSystem && model->isVaild());
-    }
-}
-
 bool AccountsDetailWidget::getOtherUserAutoLogin()
 {
     for(auto user : m_userModel->userList()) {
@@ -197,11 +225,10 @@ void AccountsDetailWidget::initUserInfo(QVBoxLayout *layout)
     m_fullName->setText(fullname.toHtmlEscaped());
     m_fullName->setElideMode(Qt::ElideRight);
 
-    m_fullNameBtn = new DIconButton(this);
+    m_fullNameBtn = new DToolButton(this);
     m_fullNameBtn->setAccessibleName("fullName_btn");
     m_fullNameBtn->setIcon(QIcon::fromTheme("dcc_edit"));
     m_fullNameBtn->setIconSize(QSize(12, 12));
-    m_fullNameBtn->setFlat(true);//设置背景透明
 
     m_inputLineEdit = new DLineEdit();
     m_inputLineEdit->setAccessibleName("fullName_edit");
@@ -235,7 +262,13 @@ void AccountsDetailWidget::initUserInfo(QVBoxLayout *layout)
     layout->addLayout(m_avatarLayout);
 
     connect(m_inputLineEdit, &DLineEdit::textEdited, this, [ = ](const QString &userFullName) {
-        if (userFullName.size() > 32) {
+        /* 90401:在键盘输入下禁止冒号的输入，粘贴情况下自动识别冒号自动删除 */
+        QString fullName = userFullName;
+        fullName.remove(":");
+        if (fullName != userFullName) {
+            m_inputLineEdit->setText(fullName);
+        }
+        if (fullName.size() > 32) {
             m_inputLineEdit->lineEdit()->backspace();
             m_inputLineEdit->setAlert(true);
             m_inputLineEdit->showAlertMessage(tr("The full name is too long"), this);
@@ -248,47 +281,7 @@ void AccountsDetailWidget::initUserInfo(QVBoxLayout *layout)
 
     connect(m_inputLineEdit, &DLineEdit::editingFinished, this, [ = ] {
         QString userFullName = m_inputLineEdit->lineEdit()->text();
-        if (userFullName == m_curUser->fullname() || (!userFullName.isEmpty() && userFullName.simplified().isEmpty())) {
-            m_inputLineEdit->lineEdit()->clearFocus();
-            m_inputLineEdit->setVisible(false);
-            m_fullName->setVisible(true);
-            m_fullNameBtn->setVisible(true);
-            if (m_inputLineEdit->isAlert()) {
-                m_inputLineEdit->setAlert(false);
-                m_inputLineEdit->hideAlertMessage();
-            }
-            return;
-        }
-        if (!userFullName.isEmpty()) {
-            QList<QString> groupList = m_userModel->getAllGroups();
-            for (QString &group : groupList) {
-                if (userFullName == group && userFullName != m_curUser->name()) {
-                    m_inputLineEdit->setAlert(true);
-                    m_inputLineEdit->showAlertMessage(tr("The name already exists"), m_inputLineEdit, 2000);
-                    m_inputLineEdit->lineEdit()->selectAll();
-                    return;
-                }
-            }
-            QList<User *> userList = m_userModel->userList();
-            for (User *user : userList) {
-                if (userFullName == user->fullname()) {
-                    m_inputLineEdit->setAlert(true);
-                    m_inputLineEdit->showAlertMessage(tr("The name already exists"), m_inputLineEdit, 2000);
-                    m_inputLineEdit->lineEdit()->selectAll();
-                    return;
-                }
-            }
-        }
-        m_inputLineEdit->lineEdit()->clearFocus();
-        m_inputLineEdit->setVisible(false);
-        m_fullName->setVisible(true);
-        m_fullNameBtn->setVisible(true);
-        if (m_inputLineEdit->isAlert()) {
-            m_inputLineEdit->setAlert(false);
-            m_inputLineEdit->hideAlertMessage();
-        }
-
-        Q_EMIT requestSetFullname(m_curUser, m_inputLineEdit->text());
+        Q_EMIT editingFinished(userFullName);
     });
 
     //点击用户图像
@@ -302,7 +295,9 @@ void AccountsDetailWidget::initUserInfo(QVBoxLayout *layout)
         if (avatar->arrowed())
         {
             avatar->setArrowed(!avatar->arrowed());
+            m_scrollArea->setVisible(false);
             m_avatarListWidget->setVisible(avatar->arrowed());
+            m_scrollArea->setVisible(true);
         }
     });
 
@@ -337,6 +332,12 @@ void AccountsDetailWidget::initUserInfo(QVBoxLayout *layout)
         m_inputLineEdit->hideAlertMessage();
         m_inputLineEdit->lineEdit()->setFocus();
     });
+
+    for(auto user : m_userModel->userList()) {
+        if (user->name() == m_userModel->getCurrentUserName()) {
+            m_curLoginUser = user;
+        }
+    }
 }
 
 void AccountsDetailWidget::initSetting(QVBoxLayout *layout)
@@ -361,81 +362,93 @@ void AccountsDetailWidget::initSetting(QVBoxLayout *layout)
     if (!IsServerSystem) {
         layout->addSpacing(20);
     }
+    // 设置密码有效期
+    auto pwHLayout = new QHBoxLayout;
+    auto pwWidget = new SettingsItem;
+    layout->addSpacing(15);
+    loginGrp->appendItem(pwWidget);
+    pwWidget->setLayout(pwHLayout);
 
-    if (m_isServerSystem) {
-        auto pwHLayout = new QHBoxLayout;
-        auto pwWidget = new SettingsItem;
-        layout->addSpacing(15);
-        loginGrp->appendItem(pwWidget);
-        pwWidget->setLayout(pwHLayout);
+    //~ contents_path /accounts/Validity Days
+    QLabel *vlidityLabel= new QLabel(tr("Validity Days"));
+    pwHLayout->addWidget(vlidityLabel, 0, Qt::AlignLeft);
+    auto validityDaysBox = new AccountSpinBox();
+    validityDaysBox->lineEdit()->setValidator(new QRegularExpressionValidator(QRegularExpression("[1-9]\\d{0,4}/^[1-9]\\d*$/"), validityDaysBox->lineEdit()));
+    validityDaysBox->lineEdit()->setPlaceholderText("99999");
+    validityDaysBox->setRange(1,99999);
+    pwHLayout->addWidget(validityDaysBox,0, Qt::AlignRight);
 
-        pwHLayout->addWidget(new QLabel(tr("Validity Days")), 0, Qt::AlignLeft);
-        auto ageEdit = new DLineEdit();
-        ageEdit->lineEdit()->setPlaceholderText(tr("Always"));
-        ageEdit->setText(m_curUser->passwordAge() >= 99999 ? tr("Always") : QString::number(m_curUser->passwordAge()));
-        ageEdit->setClearButtonEnabled(false);
-        ageEdit->lineEdit()->setValidator(new QIntValidator(1, 99999));
-        pwHLayout->addWidget(ageEdit, 0, Qt::AlignRight);
+    connect(validityDaysBox, qOverload<int>(&DSpinBox::valueChanged), this, [=](const int value) {
+        validityDaysBox->setValue(value);
+        validityDaysBox->setAlert(false);
+    });
+    connect(validityDaysBox, &QSpinBox::editingFinished, this, [this, validityDaysBox]() {
+        if (validityDaysBox->lineEdit()->text().isEmpty()) {
+            validityDaysBox->setValue(m_curUser->passwordAge());
+            return;
+        }
+        int age = validityDaysBox->value();
+        if (age == m_curUser->passwordAge())
+            return;
 
-        connect(ageEdit, &DLineEdit::textChanged, this, [ageEdit]() {
-            ageEdit->setAlert(false);
+        Q_EMIT requsetSetPassWordAge(m_curUser, validityDaysBox->value());
+    });
+    connect(m_curUser, &User::passwordAgeChanged, validityDaysBox, &AccountSpinBox::setValue);
 
-        });
-        connect(ageEdit, &DLineEdit::editingFinished, this, [this, pwWidget, ageEdit]() {
-            if (ageEdit->text().isEmpty()) {
-                ageEdit->lineEdit()->setText(m_curUser->passwordAge() >= 99999 ? tr("Always") : QString::number(m_curUser->passwordAge()));
-                return;
-            }
+    validityDaysBox->setValue(m_curUser->passwordAge());
+    validityDaysBox->valueChanged(m_curUser->passwordAge());
 
-            int age = ageEdit->text().toInt();
-
-            if (age == m_curUser->passwordAge())
-                return;
-
-            if (age <= 0) {
-                ageEdit->setAlert(true);
-                ageEdit->setAlertMessageAlignment(Qt::AlignRight);
-                ageEdit->showAlertMessage(tr("Please input a number between 1-99999"), pwWidget, 2000);
-                return;
-            }
-
-            Q_EMIT requsetSetPassWordAge(m_curUser, ageEdit->text().toInt());
-        });
-        connect(m_curUser, &User::passwordAgeChanged, this, [ageEdit](const int age) {
-            ageEdit->setText(age >= 99999 ? tr("Always") : QString::number(age));
-        });
-    }
+    const bool isVisible = m_gsettings->get(GSETTINGS_EFFECTIVE_DAY_VISIBLE).toBool();
+    pwWidget->setVisible(isVisible);
+    connect(m_gsettings, &QGSettings::changed, [=] (const QString &key){
+        if (key != GSETTINGS_EFFECTIVE_DAY_VISIBLE) {
+            return;
+        }
+        const bool isVisible = m_gsettings->get(key).toBool();
+        pwWidget->setVisible(isVisible);
+    });
 
     layout->addWidget(loginGrp);
 
-    m_fingerWidget = new FingerWidget(m_curUser, this);
-    m_fingerWidget->setContentsMargins(0, 0, 0, 0);
-    m_fingerWidget->layout()->setMargin(0);
-    layout->addSpacing(30);
-    layout->addWidget(m_fingerWidget);
+    //账户设置
+    SettingsGroup *accountSettingsGrp = new SettingsGroup(nullptr, SettingsGroup::GroupBackground);
+    //~ contents_path /accounts/Account Settings
+    m_accountSettingsTitle = new TitleLabel(tr("Account Settings"));
+    m_asAdministrator = new SwitchWidget;
+    accountSettingsGrp->getLayout()->setContentsMargins(0, 0, 0, 0);
+    accountSettingsGrp->setContentsMargins(10, 10, 10, 10);
+    accountSettingsGrp->layout()->setMargin(0);
+    accountSettingsGrp->appendItem(m_asAdministrator);
+    layout->addSpacing(20);
+    layout->addWidget(m_accountSettingsTitle);
+    layout->addWidget(accountSettingsGrp);
 
     //非当前用户不显示修改密码，自动登录，无密码登录,指纹页面
     bool isCurUser = m_curUser->isCurrentUser();
-    m_autoLogin->setEnabled(isCurUser);
-    m_nopasswdLogin->setEnabled(isCurUser);
-    m_fingerWidget->setVisible(!IsServerSystem && isCurUser);
-    //~ contents_path /accounts/Accounts Detail
-    m_modifyPassword->setText(tr("Change Password"));
-    //~ contents_path /accounts/Accounts Detail
+    m_autoLogin->switchButton()->setEnabled(isCurUser);
+    m_nopasswdLogin->switchButton()->setEnabled(isCurUser);
+    //~ contents_path /accounts/Change Password
+    m_modifyPassword->setText(m_curUser->isCurrentUser() ? tr("Change Password") : tr("Reset Password"));
+    //~ contents_path /accounts/Delete Account
     m_deleteAccount->setText(tr("Delete Account"));
-    //~ contents_path /accounts/Accounts Detail
+    //~ contents_path /accounts/Auto Login
     m_autoLogin->setTitle(tr("Auto Login"));
     m_autoLogin->setChecked(m_curUser->autoLogin());
-    //~ contents_path /accounts/Accounts Detail
+    //~ contents_path /accounts/Login Without Password
     m_nopasswdLogin->setTitle(tr("Login Without Password"));
     m_nopasswdLogin->setChecked(m_curUser->nopasswdLogin());
-
+    //~ contents_path /accounts/Administrator
+    m_asAdministrator->setTitle(tr("Administrator"));
+    m_asAdministrator->setChecked(m_curUser->userType() == User::UserType::Administrator);
     //修改密码状态判断
     connect(m_gsettings, &QGSettings::changed, this, &AccountsDetailWidget::setModifyPwdBtnStatus);
+    connect(m_curUser, &User::onlineChanged, this, [=] {
+        setModifyPwdBtnStatus("accountUserModifypasswd");
+    });
     setModifyPwdBtnStatus("accountUserModifypasswd");
 
     //修改密码
-    connect(m_modifyPassword, &QPushButton::clicked, [ = ] {
+    connect(m_modifyPassword, &QPushButton::clicked, this, [ = ] {
         Q_EMIT requestShowPwdSettings(m_curUser);
     });
 
@@ -447,8 +460,7 @@ void AccountsDetailWidget::initSetting(QVBoxLayout *layout)
 
     //自动登录，无密码登录操作
     connect(m_curUser, &User::autoLoginChanged, m_autoLogin, &SwitchWidget::setChecked);
-    connect(m_curUser, &User::nopasswdLoginChanged,
-            m_nopasswdLogin, &SwitchWidget::setChecked);
+    connect(m_curUser, &User::nopasswdLoginChanged, m_nopasswdLogin, &SwitchWidget::setChecked);
     connect(m_autoLogin, &SwitchWidget::checkedChanged,
             this, [ = ](const bool autoLogin) {
         if (autoLogin) {
@@ -484,17 +496,19 @@ void AccountsDetailWidget::initSetting(QVBoxLayout *layout)
         Q_EMIT requestNopasswdLogin(m_curUser, nopasswdLogin);
     });
 
-    //指纹界面操作
-    connect(m_fingerWidget, &FingerWidget::requestAddThumbs, this, &AccountsDetailWidget::requestAddThumbs);
-    connect(m_fingerWidget, &FingerWidget::requestCleanThumbs, this, &AccountsDetailWidget::requestCleanThumbs);
-    connect(m_fingerWidget, &FingerWidget::requestDeleteFingerItem, this, &AccountsDetailWidget::requestDeleteFingerItem);
-    connect(m_fingerWidget, &FingerWidget::requestRenameFingerItem, this, &AccountsDetailWidget::requestRenameFingerItem);
-    connect(m_fingerWidget, &FingerWidget::noticeEnrollCompleted, this, &AccountsDetailWidget::noticeEnrollCompleted);
-
     //图像列表操作
     connect(m_avatarListWidget, &AvatarListWidget::requestSetAvatar, this, [ = ](const QString & avatarPath) {
         Q_EMIT requestSetAvatar(m_curUser, avatarPath);
     });
+
+    //切换账户类型
+    connect(m_curUser, &User::userTypeChanged, this, [ = ](const int userType) {
+        m_asAdministrator->setChecked(userType == User::UserType::Administrator);
+    });
+    connect(m_asAdministrator, &SwitchWidget::checkedChanged, this, [ = ](const bool asAdministrator) {
+        Q_EMIT requestSetAdministrator(m_curUser, asAdministrator);
+    });
+
 }
 
 void AccountsDetailWidget::setAccountModel(dcc::accounts::UserModel *model)
@@ -502,7 +516,7 @@ void AccountsDetailWidget::setAccountModel(dcc::accounts::UserModel *model)
     if (!model) {
         return;
     }
-    m_userModel = model;
+
     m_autoLogin->setVisible(m_userModel->isAutoLoginVisable());
     m_nopasswdLogin->setVisible(m_userModel->isNoPassWordLoginVisable());
 
@@ -512,16 +526,30 @@ void AccountsDetailWidget::setAccountModel(dcc::accounts::UserModel *model)
         connect(m_userModel, &UserModel::noPassWordLoginVisableChanged, m_nopasswdLogin, &SwitchWidget::setVisible);
     }
 
-    auto isOnlyAdminOnDesktop = [=]() {                         // 是桌面版中的最后一个管理员
-        return !m_isServerSystem                                // 是桌面版
-                && m_curUser->userType() == User::Administrator // 是管理员
-                && m_userModel->getAdminCnt() == 1;             // 管理员只有一个
+    auto adminCnt = [=]() {
+        int adminCnt = 0;
+        for(auto user : m_userModel->userList()) {
+            if(user->userType() == User::UserType::Administrator)
+                adminCnt++;
+        }
+        return adminCnt;
+    };
+
+    auto isOnlyAdmin = [=]() {                                  // 是最后一个管理员
+        return m_curUser->userType() == User::Administrator     // 是管理员
+               && adminCnt() == 1;                              // 管理员只有一个
     };
 
     auto deleteUserBtnEnable = [=]() {      // 可以删除用户
         return !m_curUser->isCurrentUser()  // 不是当前用户
                 && !m_curUser->online()     // 未登录
-                && !isOnlyAdminOnDesktop(); // 不是桌面版的最后一个管理员
+                && !isOnlyAdmin();          // 不是最后一个管理员
+    };
+
+    auto asAdministratorEnable = [=]() {    // 可以切换账户类型
+        return !m_curUser->isCurrentUser()  // 不是当前用户
+               && !m_curUser->online()      // 未登录
+               && !isOnlyAdmin();           // 不是最后一个管理员
     };
 
     setDeleteBtnStatus("accountUserDeleteaccount", deleteUserBtnEnable());
@@ -535,6 +563,12 @@ void AccountsDetailWidget::setAccountModel(dcc::accounts::UserModel *model)
         setDeleteBtnStatus(key, deleteUserBtnEnable());
     });
 
+    m_asAdministrator->switchButton()->setEnabled(asAdministratorEnable());
+    connect(m_curUser, &User::onlineChanged, m_asAdministrator,
+            [=]() { m_asAdministrator->switchButton()->setEnabled(asAdministratorEnable()); });
+    connect(m_userModel, &UserModel::adminCntChange, m_asAdministrator,
+            [=]() { m_asAdministrator->switchButton()->setEnabled(asAdministratorEnable()); });
+
     if (!m_groupItemModel)
         return;
     m_groupItemModel->clear();
@@ -544,8 +578,14 @@ void AccountsDetailWidget::setAccountModel(dcc::accounts::UserModel *model)
         m_groupItemModel->appendRow(it);
     }
 
+    connect(m_userModel, &UserModel::allGroupsChange, this, &AccountsDetailWidget::setGroupInfo);
     changeUserGroup(m_curUser->groups());
+    onGidChanged(m_curUser->gid());
     connect(m_curUser, &User::groupsChanged, this, &AccountsDetailWidget::changeUserGroup);
+    connect(m_curUser, &User::gidChanged, this, &AccountsDetailWidget::onGidChanged);
+    connect(m_curLoginUser, &User::userTypeChanged, this, [=] {
+        setModifyPwdBtnStatus("accountUserModifypasswd");
+    });
 }
 
 void AccountsDetailWidget::initGroups(QVBoxLayout *layout)
@@ -593,6 +633,57 @@ void AccountsDetailWidget::resetDelButtonState()
     m_deleteAccount->setEnabled(true);
 }
 
+void AccountsDetailWidget::onEditingFinished(bool isValid, const QString& userFullName)
+{
+    if (userFullName == m_curUser->fullname() || (!userFullName.isEmpty() && userFullName.simplified().isEmpty())) {
+        m_inputLineEdit->lineEdit()->clearFocus();
+        m_inputLineEdit->setVisible(false);
+        m_fullName->setVisible(true);
+        m_fullNameBtn->setVisible(true);
+        if (m_inputLineEdit->isAlert()) {
+            m_inputLineEdit->setAlert(false);
+            m_inputLineEdit->hideAlertMessage();
+        }
+        return;
+    }
+    if (!userFullName.isEmpty()) {
+        if (isValid) {
+            m_inputLineEdit->setAlert(true);
+            m_inputLineEdit->showAlertMessage(tr("The name already exists"), m_inputLineEdit, 2000);
+            m_inputLineEdit->lineEdit()->selectAll();
+            return;
+        }
+        QList<User *> userList = m_userModel->userList();
+        for (User *user : userList) {
+            if (userFullName == user->fullname() || userFullName == user->name()) {
+                m_inputLineEdit->setAlert(true);
+                m_inputLineEdit->showAlertMessage(tr("The name already exists"), m_inputLineEdit, 2000);
+                m_inputLineEdit->lineEdit()->selectAll();
+                return;
+            }
+        }
+        QList<QString> groupList = m_userModel->getAllGroups();
+        for (QString &group : groupList) {
+            if (userFullName == group && userFullName != m_curUser->name()) {
+                m_inputLineEdit->setAlert(true);
+                m_inputLineEdit->showAlertMessage(tr("The name already exists"), m_inputLineEdit, 2000);
+                m_inputLineEdit->lineEdit()->selectAll();
+                return;
+            }
+        }
+    }
+    m_inputLineEdit->lineEdit()->clearFocus();
+    m_inputLineEdit->setVisible(false);
+    m_fullName->setVisible(true);
+    m_fullNameBtn->setVisible(true);
+    if (m_inputLineEdit->isAlert()) {
+        m_inputLineEdit->setAlert(false);
+        m_inputLineEdit->hideAlertMessage();
+    }
+
+    Q_EMIT requestSetFullname(m_curUser, m_inputLineEdit->text());
+}
+
 void AccountsDetailWidget::setDeleteBtnStatus(const QString &key, const bool &status)
 {
     if ("accountUserDeleteaccount" != key)
@@ -616,13 +707,18 @@ void AccountsDetailWidget::setModifyPwdBtnStatus(const QString &key)
 
     const QString btnStatus = m_gsettings->get(key).toString();
 
-    m_modifyPassword->setEnabled("Enabled" == btnStatus && m_curUser->isCurrentUser());
+    m_modifyPassword->setEnabled("Enabled" == btnStatus && ((!m_curUser->online() && m_curLoginUser->userType() == User::UserType::Administrator) || m_curUser->isCurrentUser()));
 
     m_modifyPassword->setVisible("Hidden" != btnStatus);
 }
 
 void AccountsDetailWidget::userGroupClicked(const QModelIndex &index)
 {
+    QStandardItem *item = m_groupItemModel->item(index.row(), index.column());
+    //不可移除主组
+    if(nullptr == item || item->text() == m_groupName)
+        return;
+
     QStringList curUserGroup;
     int row_count = m_groupItemModel->rowCount();
     for (int i = 0; i < row_count; ++i) {
@@ -632,7 +728,6 @@ void AccountsDetailWidget::userGroupClicked(const QModelIndex &index)
         }
     }
 
-    QStandardItem *item = m_groupItemModel->item(index.row(), index.column());
     Qt::CheckState state = item->checkState();
     state == Qt::Checked ? (void)curUserGroup.removeOne(item->text()) : curUserGroup.append(item->text());
 
@@ -645,6 +740,37 @@ void AccountsDetailWidget::changeUserGroup(const QStringList &groups)
     for (int i = 0; i < row_count; ++i) {
         QStandardItem *item = m_groupItemModel->item(i, 0);
         item->setCheckState(item && groups.contains(item->text()) ? Qt::Checked : Qt::Unchecked);
+        item->setEnabled(item->text() != m_groupName);
     }
     m_groupItemModel->sort(0);
 }
+
+void AccountsDetailWidget::setGroupInfo(const QStringList &group)
+{
+    for (const QString &item : group) {
+        GroupItem *it = new GroupItem(item);
+        it->setCheckable(false);
+        m_groupItemModel->appendRow(it);
+    }
+    changeUserGroup(m_curUser->groups());
+}
+
+void AccountsDetailWidget::onGidChanged(const QString &gid)
+{
+    bool ok;
+    int iGid = gid.toInt(&ok, 10);
+    if (!ok)
+        return;
+
+    const group *group = getgrgid(static_cast<__gid_t>(iGid));
+    if (nullptr == group || nullptr == group->gr_name)
+        return;
+
+    m_groupName = QString(group->gr_name);
+    for (int i = 0; i < m_groupItemModel->rowCount(); ++i) {
+        QStandardItem *item = m_groupItemModel->item(i, 0);
+        if (nullptr == item)
+            continue;
+        item->setEnabled(item->text() != m_groupName);
+    }
+}
