@@ -28,6 +28,7 @@
 #include <DFontSizeManager>
 #include <DDesktopServices>
 #include <DDBusSender>
+#include <DDialog>
 
 #include <QtGlobal>
 #include <QVBoxLayout>
@@ -45,19 +46,27 @@ using namespace dcc::accounts;
 using namespace dcc::widgets;
 using namespace DCC_NAMESPACE::accounts;
 
-CreateAccountPage::CreateAccountPage(QWidget *parent)
+CreateAccountPage::CreateAccountPage(dcc::accounts::AccountsWorker *accountsWorker, QWidget *parent)
     : QWidget(parent)
     , m_newUser{nullptr}
+    , m_accountWorker(accountsWorker)
     , m_avatarListWidget(nullptr)
     , m_nameEdit(new DLineEdit)
     , m_fullnameEdit(new DLineEdit)
     , m_passwdEdit(new DPasswordEdit)
     , m_repeatpasswdEdit(new DPasswordEdit)
+    , m_passwdTipsEdit(new DLineEdit)
     , m_accountChooser(new DComboBox)
     , m_groupListView(nullptr)
     , m_groupItemModel(nullptr)
     , m_groupTip(new QLabel(tr("Group")))
 {
+    m_passwdEdit->setCopyEnabled(false);
+    m_passwdEdit->setCutEnabled(false);
+
+    m_repeatpasswdEdit->setCopyEnabled(false);
+    m_repeatpasswdEdit->setCutEnabled(false);
+
     m_groupListView = new DListView(this);
     m_isServerSystem = IsServerSystem;
     QVBoxLayout *mainContentLayout = new QVBoxLayout;
@@ -192,6 +201,12 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
     layout->addWidget(m_repeatpasswdEdit);
     layout->addSpacing(7);
 
+    QLabel *passwdTipsLabel = new QLabel(tr("Password Hint") + ':');
+    m_repeatpasswdEdit->setAccessibleName("password_hint");
+    layout->addWidget(passwdTipsLabel);
+    layout->addWidget(m_passwdTipsEdit);
+    layout->addSpacing(27);
+
     connect(m_avatarListWidget, &AvatarListWidget::requestSetAvatar,
             m_avatarListWidget, &AvatarListWidget::setCurrentAvatarChecked);
     connect(m_avatarListWidget, &AvatarListWidget::requestAddNewAvatar,
@@ -220,21 +235,27 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
                 strTemp.append(strText[idx]);
             } else {
                 DDesktopServices::playSystemSoundEffect(DDesktopServices::SSE_Error);
-                break;
             }
         }
 
         m_nameEdit->lineEdit()->blockSignals(true);
+        int cursorIndex = m_nameEdit->lineEdit()->cursorPosition();
         m_nameEdit->lineEdit()->setText(strTemp);
-        m_nameEdit->lineEdit()->setCursorPosition(idx);
+        m_nameEdit->lineEdit()->setCursorPosition(cursorIndex);
         m_nameEdit->lineEdit()->blockSignals(false);
     });
 
     connect(m_nameEdit, &DLineEdit::editingFinished, this, &CreateAccountPage::checkName);
 
     connect(m_fullnameEdit, &DLineEdit::textEdited, this, [ = ](const QString &userFullName) {
+        /* 90401:在键盘输入下禁止冒号的输入，粘贴情况下自动识别冒号自动删除 */
+        QString fullName = userFullName;
+        fullName.remove(":");
+        if (fullName != userFullName) {
+            m_fullnameEdit->setText(fullName);
+        }
         /* 在输入的过程中仅检查全名的长度，输入完成后检查其它规则 */
-        if (userFullName.size() > 32) {
+        if (fullName.size() > 32) {
             m_fullnameEdit->lineEdit()->backspace();
             m_fullnameEdit->setAlert(true);
             m_fullnameEdit->showAlertMessage(tr("The full name is too long"), m_fullnameEdit, 2000);
@@ -247,6 +268,25 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
 
     connect(m_fullnameEdit, &DLineEdit::editingFinished, this, &CreateAccountPage::checkFullname);
 
+    //失焦后就提示
+    connect(m_passwdEdit, &DLineEdit::editingFinished, this, [ = ] {
+        PwqualityManager::ERROR_TYPE error = PwqualityManager::instance()->verifyPassword(m_nameEdit->lineEdit()->text(),
+                                                                                          m_passwdEdit->lineEdit()->text());
+        if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
+            m_passwdEdit->setAlert(true);
+            m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_passwdEdit, 2000);
+        }
+    });
+
+    //失焦后就提示，只检查密码一致性
+    connect(m_repeatpasswdEdit, &DLineEdit::editingFinished, this, [ = ] {
+        if (m_passwdEdit->lineEdit()->text() != m_repeatpasswdEdit->lineEdit()->text()) {
+            m_repeatpasswdEdit->setAlert(true);
+            m_repeatpasswdEdit->showAlertMessage(tr("Passwords do not match"), m_repeatpasswdEdit, 2000);
+        }
+    });
+
+
     connect(m_passwdEdit, &DPasswordEdit::textEdited, this, [ = ] {
         if (m_passwdEdit->isAlert()) {
             m_passwdEdit->hideAlertMessage();
@@ -261,6 +301,15 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
         }
     });
 
+    connect(m_passwdTipsEdit, &DLineEdit::textEdited, this, [=](const QString &passwdTips) {
+        if (passwdTips.size() > 14) {
+            m_passwdTipsEdit->lineEdit()->backspace();
+            DDesktopServices::playSystemSoundEffect(DDesktopServices::SSE_Error);
+        } else if (m_passwdTipsEdit->isAlert()) {
+            m_passwdTipsEdit->setAlert(false);
+        }
+    });
+
     connect(m_accountChooser, &DComboBox::currentTextChanged, this, &CreateAccountPage::showGroupList);
 
     m_accountChooser->addItem(tr("Standard User"));
@@ -269,16 +318,12 @@ void CreateAccountPage::initWidgets(QVBoxLayout *layout)
     if (m_isServerSystem) {
         m_accountChooser->addItem(tr("Customized"));
     }
-    if (!m_isServerSystem) {
-        accountTypeLabel->setVisible(false);
-        m_accountChooser->setVisible(false);
-        m_accountChooser->setCurrentIndex(1);
-    }
 
     m_nameEdit->lineEdit()->setPlaceholderText(tr("Required"));//必填
     m_fullnameEdit->lineEdit()->setPlaceholderText(tr("optional"));//选填
     m_passwdEdit->lineEdit()->setPlaceholderText(tr("Required"));//必填
     m_repeatpasswdEdit->lineEdit()->setPlaceholderText(tr("Required"));//必填
+    m_passwdTipsEdit->lineEdit()->setPlaceholderText(tr("optional"));//选填
 }
 
 void CreateAccountPage::showGroupList(const QString &index)
@@ -320,10 +365,12 @@ void CreateAccountPage::setModel(UserModel *userModel, User *user)
     m_groupItemModel->sort(0);
 }
 
-//在修改密码页面当前密码处设置焦点
+//在修改密码页面设置默认焦点
 void CreateAccountPage::showEvent(QShowEvent *event)
 {
-    if (m_nameEdit && !m_nameEdit->hasFocus()) {
+    if (m_accountChooser && m_accountChooser->isVisible() && m_accountChooser->isEnabled())
+        m_accountChooser->setFocus();
+    else if (m_nameEdit && !m_nameEdit->hasFocus()) {
         m_nameEdit->lineEdit()->setFocus();
     }
     QWidget::showEvent(event);
@@ -331,11 +378,37 @@ void CreateAccountPage::showEvent(QShowEvent *event)
 
 void CreateAccountPage::createUser()
 {
+    bool check = false;
     //校验输入的用户名和密码
-    if (!checkName() || !checkFullname() || !checkPassword(m_repeatpasswdEdit) || !checkPassword(m_passwdEdit)) {
+    if (!checkName()) {
+        check = true;
+    }
+
+    if (!checkFullname()) {
+        check = true;
+    }
+
+    if (!checkPassword(m_repeatpasswdEdit)) {
+        check = true;
+    }
+
+    if (!checkPassword(m_passwdEdit)) {
+        check = true;
+    }
+
+
+    if (check) {
         return;
     }
 
+    for (auto c : m_passwdEdit->text()) {
+        if (m_passwdTipsEdit->text().contains(c)) {
+            m_passwdTipsEdit->setAlert(true);
+            m_passwdTipsEdit->showAlertMessage(tr("The hint is visible to all users. Do not include the password here."), m_passwdTipsEdit, 2000);
+            return;
+        }
+    }
+
     //如果用户没有选图像
     auto avatarPaht = m_avatarListWidget->getAvatarPath();
     m_newUser->setCurrentAvatar(avatarPaht);
@@ -343,6 +416,7 @@ void CreateAccountPage::createUser()
     m_newUser->setFullname(m_fullnameEdit->lineEdit()->text());
     m_newUser->setPassword(m_passwdEdit->lineEdit()->text());
     m_newUser->setRepeatPassword(m_repeatpasswdEdit->lineEdit()->text());
+    m_newUser->setPasswordHint(m_passwdTipsEdit->lineEdit()->text());
 
     /* 设置用户组 */
     if (m_accountChooser->currentIndex() == 1) {
@@ -367,7 +441,7 @@ void CreateAccountPage::createUser()
 void CreateAccountPage::setCreationResult(CreationResult *result)
 {
     switch (result->type()) {
-    case CreationResult::NoError:
+    case CreationResult::NoError:      
         Q_EMIT requestBack(AccountsWidget::CreateUserSuccess);
         break;
     case CreationResult::UserNameError:
@@ -423,14 +497,13 @@ bool CreateAccountPage::checkName()
         return false;
     }
 
-    QList<QString> groupList = m_userModel->getAllGroups();
-    for (QString &group : groupList) {
-        if (userName == group) {
-            m_nameEdit->setAlert(true);
-            m_nameEdit->showAlertMessage(tr("The name already exists"), m_nameEdit, 2000);
-            return false;
-        }
+    if (!m_accountWorker->isUsernameValid(userName).argumentAt(0).toBool() && NAME_ALREADY == m_accountWorker->isUsernameValid(userName).argumentAt(2).toInt()) {
+        m_nameEdit->setAlert(true);
+        m_nameEdit->showAlertMessage(tr("The name already exists"), m_nameEdit, 2000);
+        return false;
     }
+
+
     /* 暂时先屏蔽用户名与用户全名的重复性检查 */
     // QList<User *> userList = m_userModel->userList();
     // for (User *user : userList) {
@@ -459,21 +532,29 @@ bool CreateAccountPage::checkFullname()
         return false;
     }
 
+    //欧拉版会自己创建shutdown等root组账户且不会添加到userList中，导致无法重复性算法无效，先通过isUsernameValid校验这些账户再通过重复性算法校验
+    //vaild == false && code ==6 是用户名已存在
+    if (!m_accountWorker->isUsernameValid(userFullName).argumentAt(0).toBool() && ErrCodeSystemUsed == m_accountWorker->isUsernameValid(userFullName).argumentAt(2).toInt()) {
+        m_fullnameEdit->setAlert(true);
+        m_fullnameEdit->showAlertMessage(tr("The name already exists"), m_fullnameEdit, 2000);
+        m_fullnameEdit->lineEdit()->selectAll();
+        return false;
+    }
+
     if (!userFullName.simplified().isEmpty()) {
-        QList<QString> groupList = m_userModel->getAllGroups();
-        /* 与系统中已有的用户名和用户组进行重复性校验 */
-        for (QString &group : groupList) {
-            if (userFullName == group) {
+        QList<User *> userList = m_userModel->userList();
+        /* 与已有的用户全名和用户名进行重复性校验 */
+        for (User *user : userList) {
+            if (userFullName == user->fullname() || userFullName == user->name()) {
                 m_fullnameEdit->setAlert(true);
-                m_fullnameEdit->showAlertMessage(tr("The name already exists"), m_fullnameEdit, 2000);
+                m_fullnameEdit->showAlertMessage(tr("The username already exists"), m_fullnameEdit, 2000);
                 m_fullnameEdit->lineEdit()->selectAll();
                 return false;
             }
         }
-        QList<User *> userList = m_userModel->userList();
-        /* 与已有的用户全名进行重复性校验 */
-        for (User *user : userList) {
-            if (userFullName == user->fullname()) {
+        QList<QString> groupList = m_userModel->getAllGroups();
+        for (QString &group : groupList) {
+            if (userFullName == group) {
                 m_fullnameEdit->setAlert(true);
                 m_fullnameEdit->showAlertMessage(tr("The name already exists"), m_fullnameEdit, 2000);
                 m_fullnameEdit->lineEdit()->selectAll();
@@ -507,7 +588,7 @@ bool CreateAccountPage::checkPassword(DPasswordEdit *edit)
 
     if (error != PwqualityManager::ERROR_TYPE::PW_NO_ERR) {
         m_passwdEdit->setAlert(true);
-        m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error));
+        m_passwdEdit->showAlertMessage(PwqualityManager::instance()->getErrorTips(error), m_passwdEdit, 2000);
 
         // 企业版控制中心用户创建屏蔽安全中心登录安全的接口需求
         if ((DSysInfo::uosEditionType() == DSysInfo::UosEnterprise) || (DSysInfo::uosEditionType() == DSysInfo::UosEnterpriseC))
@@ -519,8 +600,8 @@ bool CreateAccountPage::checkPassword(DPasswordEdit *edit)
         if (!interface.isValid()) {
             return false;
         }
-        QDBusReply<int> level = interface.call("GetPwdLimitLevel");
 
+        QDBusReply<int> level = interface.call("GetPwdLimitLevel");
         if (level != 1) {
             QDBusReply<QString> errorTips = interface.call("GetPwdError");
             DDialog dlg("", errorTips, this);
