@@ -31,11 +31,16 @@
 #include "modules/display/displaymodel.h"
 #include "modules/display/monitorcontrolwidget.h"
 #include "modules/display/monitorindicator.h"
+#include "modules/display/recognizewidget.h"
 #include "window/gsettingwatcher.h"
+#include "window/dconfigwatcher.h"
 
 #include <QVBoxLayout>
 #include <QApplication>
 #include <QComboBox>
+#include <QDesktopWidget>
+#include <QScreen>
+#include <QKeyEvent>
 
 using namespace dcc::widgets;
 using namespace dcc::display;
@@ -46,30 +51,39 @@ const int ComboxWidth = 300;
 
 MultiScreenWidget::MultiScreenWidget(QWidget *parent)
     : QWidget(parent)
-    , m_contentLayout(new QVBoxLayout)
-    , m_monitorControlWidget(new MonitorControlWidget)
-    , m_fullIndication(new MonitorIndicator)
-    , m_multiSettingLabel(new TitleLabel(tr("Multiple Displays")))
-    , m_modeSettingsItem(new SettingsItem)
-    , m_modeLabel(new QLabel(tr("Mode")))
-    , m_modeCombox(new QComboBox)
-    , m_primarySettingsItem(new SettingsItem)
-    , m_primaryLabel(new QLabel(tr("Main Screen")))
-    , m_primaryCombox(new QComboBox)
+    , m_contentLayout(new QVBoxLayout(this))
+    , m_monitorControlWidget(new MonitorControlWidget(240, this)) //根据产品设计更改出事高度为240
+    , m_fullIndication(new MonitorIndicator(this))
+    , m_modeSettingsItem(new SettingsItem(this))
+    , m_modeCombox(new QComboBox(this))
+    , m_primarySettingsItem(new SettingsItem(this))
+    , m_primaryCombox(new QComboBox(this))
     , m_brightnessSpacerItem(new QSpacerItem(0, 20))
-    , m_brightnessWidget(new BrightnessWidget)
-    , m_scalingWidget(new ScalingWidget)
-    , m_resolutionWidget(new ResolutionWidget)
-    , m_refreshRateWidget(new RefreshRateWidget)
-    , m_rotateWidget(new RotateWidget)
+    , m_brightnessWidget(new BrightnessWidget(this))
+    , m_scalingWidget(new ScalingWidget(this))
+    , m_resolutionWidget(new ResolutionWidget(300, this))
+    , m_refreshRateWidget(new RefreshRateWidget(300, this))
+    , m_rotateWidget(new RotateWidget(300, this))
     , m_model(nullptr)
+    , m_resetSecondaryScreenDlgTimer(new QTimer(this))
 {
+    //初始化列表无法进行静态翻译
+    //~ contents_path /display/Multiple Displays
+    m_multiSettingLabel = new TitleLabel(tr("Multiple Displays"), this);
+    //~ contents_path /display/Mode
+    m_modeLabel = new QLabel(tr("Mode"), this);
+    //~ contents_path /display/Main Scree
+    m_primaryLabel = new QLabel(tr("Main Screen"), this);
+
+    m_monitorControlWidget->setAccessibleName("MultiScreenWidget_monitorControl");
+    m_fullIndication->setAccessibleName("fullIndication");
+
     m_contentLayout->setSpacing(0);
     m_contentLayout->setContentsMargins(56, 20, 56, 0);
     m_contentLayout->addWidget(m_monitorControlWidget);
     m_contentLayout->addSpacing(20);
     m_contentLayout->addWidget(m_multiSettingLabel);
-    QHBoxLayout *modeLayout = new QHBoxLayout;
+    QHBoxLayout *modeLayout = new QHBoxLayout(m_modeSettingsItem);
     modeLayout->setContentsMargins(10, 0, 10, 0);
     modeLayout->addWidget(m_modeLabel);
     modeLayout->addWidget(m_modeCombox);
@@ -82,7 +96,7 @@ MultiScreenWidget::MultiScreenWidget(QWidget *parent)
     m_contentLayout->addSpacing(10);
     m_contentLayout->addWidget(m_modeSettingsItem);
 
-    QHBoxLayout *primaryLayout = new QHBoxLayout;
+    QHBoxLayout *primaryLayout = new QHBoxLayout(m_primarySettingsItem);
     primaryLayout->setContentsMargins(10, 0, 10, 0);
     primaryLayout->addWidget(m_primaryLabel);
     primaryLayout->addWidget(m_primaryCombox);
@@ -116,6 +130,17 @@ MultiScreenWidget::MultiScreenWidget(QWidget *parent)
     GSettingWatcher::instance()->bind("displayMultipleDisplays", m_multiSettingLabel);
     GSettingWatcher::instance()->bind("displayMultipleDisplays", m_modeSettingsItem);
     GSettingWatcher::instance()->bind("displayMultipleDisplays", m_primarySettingsItem);
+    connect(GSettingWatcher::instance(), SIGNAL(notifyGSettingsChanged(const QString &, const QString &)), this, SLOT(onGSettingsChanged(const QString &, const QString &)));
+// 先屏蔽dconfig配置,待后续进行配置迁移时统一替换为dconfig配置
+//    DConfigWatcher::instance()->bind(DConfigWatcher::display,"mainScreen", m_primarySettingsItem);
+//    DConfigWatcher::instance()->bind(DConfigWatcher::display,"multiscreenMode", m_modeSettingsItem);
+
+    QDesktopWidget *desktopwidget = QApplication::desktop();
+    connect(desktopwidget,SIGNAL(resized(int)),this,SLOT(onResetSecondaryScreenDlg()));
+
+    m_resetSecondaryScreenDlgTimer->setSingleShot(true);
+    m_resetSecondaryScreenDlgTimer->setInterval(100);
+    connect(m_resetSecondaryScreenDlgTimer, &QTimer::timeout, this, &MultiScreenWidget::onResetSecondaryScreenDlgTimerOut);
 }
 
 MultiScreenWidget::~MultiScreenWidget()
@@ -125,12 +150,22 @@ MultiScreenWidget::~MultiScreenWidget()
     }
     m_secondaryScreenDlgList.clear();
 
+    for(auto widget : m_recognizeWidget) {
+        widget->deleteLater();
+    }
+    m_recognizeWidget.clear();
+    delete m_fullIndication;
+
     GSettingWatcher::instance()->erase("displayResolution", m_resolutionWidget);
     GSettingWatcher::instance()->erase("displayRefreshRate", m_refreshRateWidget);
     GSettingWatcher::instance()->erase("displayRotate", m_rotateWidget);
     GSettingWatcher::instance()->erase("displayMultipleDisplays", m_multiSettingLabel);
     GSettingWatcher::instance()->erase("displayMultipleDisplays", m_modeSettingsItem);
     GSettingWatcher::instance()->erase("displayMultipleDisplays", m_primarySettingsItem);
+// 先屏蔽dconfig配置,待后续进行配置迁移时统一替换为dconfig配置
+//    DConfigWatcher::instance()->erase(DConfigWatcher::display,"mainScreen", m_primarySettingsItem);
+//    DConfigWatcher::instance()->erase(DConfigWatcher::display,"multiscreenMode", m_modeSettingsItem);
+
 }
 
 void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
@@ -144,7 +179,7 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
     connect(m_model, &DisplayModel::displayModeChanged, this, [=](const int mode) {
         if (mode == MERGE_MODE) {
             m_modeCombox->setCurrentIndex(0);
-            m_primaryCombox->setEnabled(false);
+            m_primarySettingsItem->setVisible(false);
             m_brightnessWidget->showBrightness();
             m_monitorControlWidget->setModel(m_model);
             for (auto dlg : m_secondaryScreenDlgList) {
@@ -153,7 +188,7 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
             m_secondaryScreenDlgList.clear();
         } else if (mode == EXTEND_MODE) {
             m_modeCombox->setCurrentIndex(1);
-            m_primaryCombox->setEnabled(true);
+            m_primarySettingsItem->setVisible(true);
             m_brightnessWidget->showBrightness(m_model->primaryMonitor());
             m_monitorControlWidget->setModel(m_model);
             initSecondaryScreenDialog();
@@ -168,7 +203,7 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
                 }
             }
 
-            m_primaryCombox->setEnabled(false);
+            m_primarySettingsItem->setVisible(false);
             m_brightnessWidget->showBrightness(m_model->primaryMonitor());
 
             for (auto dlg : m_secondaryScreenDlgList) {
@@ -194,6 +229,14 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
         } else if (m_model->displayMode() == SINGLE_MODE) {
             m_monitorControlWidget->setModel(m_model, m_model->primaryMonitor());
             m_brightnessWidget->showBrightness(m_model->primaryMonitor());
+            auto monitorList = m_model->monitorList();
+            for (int idx = 0; idx < monitorList.size(); ++idx) {
+                auto monitor = monitorList[idx];
+                if (monitor->enable()) {
+                    m_modeCombox->setCurrentIndex(idx + 2);
+                    break;
+                }
+            }
         }
 
         m_resolutionWidget->setMonitor(m_model->primaryMonitor());
@@ -202,9 +245,19 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
 
         for (const auto &monitor : m_model->monitorList()) {
             if (name == monitor->name()) {
-                m_fullIndication->setGeometry(monitor->rect());
+                for (auto screen : QGuiApplication::screens()) {
+                    disconnect(screen, &QScreen::geometryChanged, this, &MultiScreenWidget::onResetFullIndication);
+                }
+                QScreen *screen = m_model->primaryMonitor()->getQScreen();
+                if(!screen)
+                    continue;
+
+                connect(screen, &QScreen::geometryChanged, this, &MultiScreenWidget::onResetFullIndication);
+
+                m_fullIndication->setGeometry(screen->geometry());
+                m_fullIndication->move(screen->geometry().topLeft());
                 m_fullIndication->setVisible(true);
-                QTimer::singleShot(500, this, [=] { m_fullIndication->setVisible(false); });
+                QTimer::singleShot(1000, this, [=] { m_fullIndication->setVisible(false); });
                 break;
             }
         }
@@ -213,9 +266,7 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
         initSecondaryScreenDialog();
     });
     connect(m_model, &DisplayModel::resolutionRefreshEnableChanged, this, [=](const bool enable) {
-        m_multiSettingLabel->setVisible(GSettingWatcher::instance()->getStatus("displayMultipleDisplays") != "Hidden" ? enable : false);
-        m_modeSettingsItem->setVisible(enable);
-        m_primarySettingsItem->setVisible(enable);
+        onGSettingsChanged("displayMultipleDisplays", GSettingWatcher::instance()->getStatus("displayMultipleDisplays"));
     });
     connect(m_model, &DisplayModel::brightnessEnableChanged, this, [=](const bool enable) {
         m_brightnessSpacerItem->changeSize(0, enable ? 20 : 0);
@@ -225,14 +276,16 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
     connect(m_monitorControlWidget, &MonitorControlWidget::requestMonitorPress, this, &MultiScreenWidget::onMonitorPress);
     connect(m_monitorControlWidget, &MonitorControlWidget::requestMonitorRelease, this, &MultiScreenWidget::onMonitorRelease);
     connect(m_monitorControlWidget, &MonitorControlWidget::requestRecognize, this, &MultiScreenWidget::requestRecognize);
-    connect(m_monitorControlWidget, &MonitorControlWidget::requestSetMonitorPosition, this, &MultiScreenWidget::requestSetMonitorPosition);
+    connect(m_monitorControlWidget, &MonitorControlWidget::requestSetMonitorPosition, this, &MultiScreenWidget::onRequestSetMonitorPosition);
     connect(m_monitorControlWidget, &MonitorControlWidget::requestGatherWindows, this, &MultiScreenWidget::onGatherWindows);
     connect(this, &MultiScreenWidget::requestGatherEnabled, m_monitorControlWidget, &MonitorControlWidget::onGatherEnabled);
 
     connect(m_modeCombox, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, [=](int idx) {
         if (idx <= 1 && m_model->displayMode() != idx + 1) {
+            m_monitorControlWidget->setMergeMode((idx == 0)? true: false);
             Q_EMIT requestSwitchMode(idx + 1);
-        } else if (idx > 1 && (m_model->displayMode() != SINGLE_MODE || m_model->monitorList()[idx - 2]->name() != m_model->primary())) {
+        } else if (idx > 1 && (m_model->displayMode() != SINGLE_MODE || (m_model->monitorList()[idx - 2]->name() != m_model->primary() && !m_model->primary().isEmpty()))) {
+            m_monitorControlWidget->setMergeMode(false);
             Q_EMIT requestSwitchMode(SINGLE_MODE, m_model->monitorList()[idx - 2]->name());
         }
     });
@@ -246,15 +299,18 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
     connect(m_brightnessWidget, &BrightnessWidget::requestSetMethodAdjustCCT, this, &MultiScreenWidget::requestSetMethodAdjustCCT);
     connect(m_scalingWidget, &ScalingWidget::requestUiScaleChange, this, &MultiScreenWidget::requestUiScaleChange);
     connect(m_resolutionWidget, &ResolutionWidget::requestSetResolution, this, &MultiScreenWidget::requestSetResolution);
+    connect(m_resolutionWidget, &ResolutionWidget::requestSetFillMode, this, &MultiScreenWidget::requestSetFillMode);
+    connect(m_resolutionWidget, &ResolutionWidget::requestCurrFillModeChanged, this, &MultiScreenWidget::requestCurrFillModeChanged);
     connect(m_refreshRateWidget, &RefreshRateWidget::requestSetResolution, this, &MultiScreenWidget::requestSetResolution);
     connect(m_rotateWidget, &RotateWidget::requestSetRotate, this, &MultiScreenWidget::requestSetRotate);
 
+    connect(this, &MultiScreenWidget::requestRecognize, this, &MultiScreenWidget::onRequestRecognize);
+
     m_monitorControlWidget->setScreensMerged(m_model->displayMode());
     m_monitorControlWidget->setModel(m_model, m_model->displayMode() == SINGLE_MODE ? m_model->primaryMonitor() : nullptr);
-    m_multiSettingLabel->setVisible(m_model->resolutionRefreshEnable() && (GSettingWatcher::instance()->getStatus("displayMultipleDisplays") != "Hidden"));
-    m_modeSettingsItem->setVisible(m_model->resolutionRefreshEnable());
-    m_primarySettingsItem->setVisible(m_model->resolutionRefreshEnable());
-    m_primaryCombox->setEnabled(m_model->displayMode() == EXTEND_MODE);
+
+    onGSettingsChanged("displayMultipleDisplays", GSettingWatcher::instance()->getStatus("displayMultipleDisplays"));
+
     m_brightnessWidget->setMode(m_model);
     m_brightnessWidget->showBrightness(m_model->displayMode() == MERGE_MODE ? nullptr : m_model->primaryMonitor());
     m_brightnessWidget->setVisible(m_model->brightnessEnable());
@@ -267,6 +323,20 @@ void MultiScreenWidget::setModel(dcc::display::DisplayModel *model)
     initSecondaryScreenDialog();
 }
 
+void MultiScreenWidget::onGSettingsChanged(const QString &gsettingsName, const QString &setting)
+{
+    if (m_model && gsettingsName == "displayMultipleDisplays" && !setting.isEmpty()) {
+        bool multipleDisplays = m_model->resolutionRefreshEnable() && (setting != "Hidden");
+        m_multiSettingLabel->setVisible(multipleDisplays);
+        m_modeSettingsItem->setVisible(multipleDisplays);
+        m_primarySettingsItem->setVisible(multipleDisplays && m_model->displayMode() == EXTEND_MODE);
+        bool multipleEnable = m_model->resolutionRefreshEnable() && (setting != "Disabled");
+        m_multiSettingLabel->setEnabled(multipleEnable);
+        m_modeSettingsItem->setEnabled(multipleEnable);
+        m_primarySettingsItem->setEnabled(multipleEnable);
+    }
+}
+
 void MultiScreenWidget::initModeList()
 {
     m_modeCombox->addItem(tr("Duplicate"));
@@ -275,7 +345,9 @@ void MultiScreenWidget::initModeList()
     auto monitorList = m_model->monitorList();
     for (int idx = 0; idx < monitorList.size(); ++idx) {
         auto monitor = monitorList[idx];
-        m_modeCombox->addItem(tr("Only on %1").arg(monitor->name()));
+        if(monitorList.size() <= 2)
+            m_modeCombox->addItem(tr("Only on %1").arg(monitor->name()));
+
         if (m_model->displayMode() == MERGE_MODE) {
             m_modeCombox->setCurrentIndex(0);
         } else if (m_model->displayMode() == EXTEND_MODE) {
@@ -299,6 +371,7 @@ void MultiScreenWidget::initPrimaryList()
 void MultiScreenWidget::initSecondaryScreenDialog()
 {
     if (m_model->displayMode() == EXTEND_MODE) {
+        m_resetSecondaryScreenDlgTimer->stop();
         for (auto dlg : m_secondaryScreenDlgList) {
             dlg->deleteLater();
         }
@@ -306,23 +379,34 @@ void MultiScreenWidget::initSecondaryScreenDialog()
 
         for (const auto &monitor : m_model->monitorList()) {
             if (monitor == m_model->primaryMonitor()) {
-                QTimer::singleShot(0, this, [=] { requestSetMainwindowRect(m_model->primaryMonitor()); });
+                QTimer::singleShot(0, this, [=] { requestSetMainwindowRect(m_model->primaryMonitor(), true); });
                 continue;
             }
 
-            m_dlg = new SecondaryScreenDialog(this);
-            m_dlg->setModel(m_model, monitor);
-            connect(m_dlg, &SecondaryScreenDialog::requestRecognize, this, &MultiScreenWidget::requestRecognize);
-            connect(m_dlg, &SecondaryScreenDialog::requestSetMonitorBrightness, this, &MultiScreenWidget::requestSetMonitorBrightness);
-            connect(m_dlg, &SecondaryScreenDialog::requestAmbientLightAdjustBrightness, this, &MultiScreenWidget::requestAmbientLightAdjustBrightness);
-            connect(m_dlg, &SecondaryScreenDialog::requestSetResolution, this, &MultiScreenWidget::requestSetResolution);
-            connect(m_dlg, &SecondaryScreenDialog::requestSetRotate, this, &MultiScreenWidget::requestSetRotate);
-            connect(m_dlg, &SecondaryScreenDialog::requestGatherWindows, this, &MultiScreenWidget::onGatherWindows);
-            connect(this, &MultiScreenWidget::requestGatherEnabled, m_dlg, &SecondaryScreenDialog::requestGatherEnabled);
-            m_secondaryScreenDlgList.append(m_dlg);
+            SecondaryScreenDialog *dlg = new SecondaryScreenDialog(this);
+            dlg->setAttribute(Qt::WA_WState_WindowOpacitySet);
+            dlg->setModel(m_model, monitor);
+            connect(dlg, &SecondaryScreenDialog::requestRecognize, this, &MultiScreenWidget::requestRecognize);
+            connect(dlg, &SecondaryScreenDialog::requestSetMonitorBrightness, this, &MultiScreenWidget::requestSetMonitorBrightness);
+            connect(dlg, &SecondaryScreenDialog::requestAmbientLightAdjustBrightness, this, &MultiScreenWidget::requestAmbientLightAdjustBrightness);
+            connect(dlg, &SecondaryScreenDialog::requestSetResolution, this, &MultiScreenWidget::requestSetResolution);
+            connect(dlg, &SecondaryScreenDialog::requestSetFillMode, this, &MultiScreenWidget::requestSetFillMode);
+            connect(dlg, &SecondaryScreenDialog::requestCurrFillModeChanged, this, &MultiScreenWidget::requestCurrFillModeChanged);
+            connect(dlg, &SecondaryScreenDialog::requestSetRotate, this, &MultiScreenWidget::requestSetRotate);
+            connect(dlg, &SecondaryScreenDialog::requestGatherWindows, this, &MultiScreenWidget::onGatherWindows);
+            connect(dlg, &SecondaryScreenDialog::requestCloseRecognize, this, &MultiScreenWidget::onRequestCloseRecognize);
+            connect(this, &MultiScreenWidget::requestGatherEnabled, dlg, &SecondaryScreenDialog::requestGatherEnabled);
+            m_secondaryScreenDlgList.append(dlg);
+            
+            dlg->show();
         }
-
         activateWindow();
+
+        if (!qgetenv("WAYLAND_DISPLAY").isEmpty()) {
+            m_resetSecondaryScreenDlgTimer->start();
+        } else {
+            onResetSecondaryScreenDlgTimerOut();
+        }
     }
 }
 
@@ -366,15 +450,101 @@ void MultiScreenWidget::onGatherWindows(const QPoint cursor)
 
 void MultiScreenWidget::onMonitorPress(Monitor *monitor)
 {
-    m_fullIndication->setGeometry(monitor->rect());
+    QScreen *screen = monitor->getQScreen();
+    if(!screen)
+        return;
 
+    m_fullIndication->setGeometry(screen->geometry());
+    m_fullIndication->move(screen->geometry().topLeft());
     m_fullIndication->setVisible(true);
+
+    QTimer::singleShot(1000, this, [=] { m_fullIndication->setVisible(false); });
 }
 
 void MultiScreenWidget::onMonitorRelease(Monitor *monitor)
 {
     Q_UNUSED(monitor)
     m_fullIndication->setVisible(false);
-    QTimer::singleShot(1000, this, [=] { requestSetMainwindowRect(m_model->primaryMonitor()); });
-    m_dlg->resetDialog();
+    QTimer::singleShot(1000, this, [=] { requestSetMainwindowRect(m_model->primaryMonitor(), false); });
+}
+
+void MultiScreenWidget::onRequestSetMonitorPosition(QHash<dcc::display::Monitor *, QPair<int, int>> monitorPosition)
+{
+    Q_EMIT requestSetMonitorPosition(monitorPosition);
+}
+
+void MultiScreenWidget::onResetFullIndication(const QRect &geometry)
+{
+    m_fullIndication->setGeometry(geometry);
+    m_fullIndication->move(geometry.topLeft());
+}
+
+void MultiScreenWidget::onResetSecondaryScreenDlgTimerOut()
+{
+    for (auto dlg : m_secondaryScreenDlgList) {
+        dlg->resetDialog();
+    }
+}
+
+void MultiScreenWidget::onResetSecondaryScreenDlg()
+{
+    for (int i = 0; i < m_secondaryScreenDlgList.count(); ++i) {
+        SecondaryScreenDialog *screenDialog = m_secondaryScreenDlgList.at(i);
+        Q_ASSERT(screenDialog);
+        screenDialog->setWindowOpacity(1);
+        screenDialog->resetDialog();
+    }
+}
+
+void MultiScreenWidget::onRequestRecognize()
+{
+    for(auto widget : m_recognizeWidget) {
+        widget->deleteLater();
+    }
+    m_recognizeWidget.clear();
+
+    // 复制模式
+    if (m_model->displayMode() == MERGE_MODE) {
+        QString text = m_model->monitorList().first()->name();
+        for (int idx = 1; idx < m_model->monitorList().size(); idx++) {
+            text += QString(" = %1").arg(m_model->monitorList()[idx]->name());
+        }
+
+        // 所在显示器不存在显示框
+        if (m_recognizeWidget.value(text) == nullptr) {
+            dcc::display::RecognizeWidget *widget = new dcc::display::RecognizeWidget(m_model->monitorList()[0], text);
+            m_recognizeWidget[text] = widget;
+        }
+    } else { // 扩展模式
+        for (auto monitor : m_model->monitorList()) {
+            // 所在显示器不存在显示框
+            if (m_recognizeWidget.value(monitor->name()) == nullptr) {
+                dcc::display::RecognizeWidget *widget = new dcc::display::RecognizeWidget(monitor, monitor->name());
+                m_recognizeWidget[monitor->name()] = widget;
+            }
+        }
+    }
+
+    this->setFocus(); //获取焦点响应键盘事件
+}
+
+void MultiScreenWidget::onRequestCloseRecognize()
+{
+    disconnect(this, &MultiScreenWidget::requestRecognize, this, &MultiScreenWidget::onRequestRecognize);
+
+    for(auto widget : m_recognizeWidget) {
+        widget->deleteLater();
+    }
+    m_recognizeWidget.clear();
+
+    connect(this, &MultiScreenWidget::requestRecognize, this, &MultiScreenWidget::onRequestRecognize);
+}
+
+void MultiScreenWidget::keyPressEvent(QKeyEvent *e)
+{
+    if(e->key() == Qt::Key_Escape) {
+        onRequestCloseRecognize();
+    }
+
+    QWidget::keyPressEvent(e);
 }
