@@ -46,6 +46,7 @@ ShortCutSettingWidget::ShortCutSettingWidget(ShortcutModel *model, QWidget *pare
     , m_assistiveToolsGroup(nullptr)
     , m_model(model)
 {
+    setAccessibleName("ShortCutSettingWidget");
     m_searchDelayTimer = new QTimer(this);
     m_searchDelayTimer->setInterval(300);
     m_searchDelayTimer->setSingleShot(true);
@@ -53,6 +54,8 @@ ShortCutSettingWidget::ShortCutSettingWidget(ShortcutModel *model, QWidget *pare
     m_searchText = QString();
     SettingsHead *systemHead = new SettingsHead();
     systemHead->setEditEnable(false);
+    //~ contents_path /keyboard/Shortcuts
+    //~ child_page Shortcuts
     systemHead->setTitle(tr("System"));
     systemHead->layout()->setContentsMargins(10, 0, 10, 0);
     m_systemGroup = new SettingsGroup();
@@ -61,6 +64,8 @@ ShortCutSettingWidget::ShortCutSettingWidget(ShortcutModel *model, QWidget *pare
 
     SettingsHead *windowHead = new SettingsHead();
     windowHead->setEditEnable(false);
+    //~ contents_path /keyboard/Shortcuts
+    //~ child_page Shortcuts
     windowHead->setTitle(tr("Window"));
     windowHead->layout()->setContentsMargins(10, 0, 10, 0);
     m_windowGroup = new SettingsGroup();
@@ -70,6 +75,8 @@ ShortCutSettingWidget::ShortCutSettingWidget(ShortcutModel *model, QWidget *pare
     if (!DCC_NAMESPACE::IsServerSystem) {
         m_workspaceHead = new SettingsHead();
         m_workspaceHead->setEditEnable(false);
+        //~ contents_path /keyboard/Shortcuts
+        //~ child_page Shortcuts
         m_workspaceHead->setTitle(tr("Workspace"));
         m_workspaceHead->layout()->setContentsMargins(10, 0, 10, 0);
         m_workspaceGroup = new SettingsGroup();
@@ -78,6 +85,8 @@ ShortCutSettingWidget::ShortCutSettingWidget(ShortcutModel *model, QWidget *pare
 
     if (!DCC_NAMESPACE::IsServerSystem && !DSysInfo::isCommunityEdition()) {
         SettingsHead *speechHead = new SettingsHead();
+        //~ contents_path /keyboard/Shortcuts
+        //~ child_page Shortcuts
         speechHead->setTitle(tr("Assistive Tools"));
         speechHead->setEditEnable(false);
         speechHead->layout()->setContentsMargins(10, 0, 10, 0);
@@ -90,10 +99,13 @@ ShortCutSettingWidget::ShortCutSettingWidget(ShortcutModel *model, QWidget *pare
     m_searchInput = new SearchInput();
     m_searchInput->setContentsMargins(0, 0, 10, 0);
     m_searchInput->setAccessibleName("KEYBOARD_LINEEDIT");
+    m_searchInput->setObjectName("KeyboardLineEdit");
 
     m_head = new SettingsHead();
     m_head->setEditEnable(true);
     m_head->setVisible(false);
+    //~ contents_path /keyboard/Shortcuts
+    //~ child_page Shortcuts
     m_head->setTitle(tr("Custom Shortcut"));
     m_head->layout()->setContentsMargins(10, 0, 10, 0);
     m_customGroup->appendItem(m_head, SettingsGroup::NoneBackground);
@@ -134,8 +146,11 @@ ShortCutSettingWidget::ShortCutSettingWidget(ShortcutModel *model, QWidget *pare
     m_layout->addStretch();
 
     QWidget *widget = new QWidget(this);
+    widget->setAccessibleName("ShortCutSettingWidget_widget");
+    widget->setContentsMargins(0, 0, 0, 0);
     widget->setLayout(m_layout);
     ContentWidget *contentWidget = new ContentWidget(this);
+    contentWidget->setAccessibleName("ShortCutSettingWidget_ContentWidget");
     contentWidget->setContent(widget);
     vlayout->addWidget(contentWidget);
 
@@ -143,13 +158,13 @@ ShortCutSettingWidget::ShortCutSettingWidget(ShortcutModel *model, QWidget *pare
     m_searchInput->hide();
 
     m_addCustomShortcut = new DFloatingButton(DStyle::SP_IncreaseElement, this);
-
+    m_addCustomShortcut->setObjectName("AddCustomShortCut");
     QHBoxLayout *btnLayout = new QHBoxLayout;
     btnLayout->setMargin(0);
     btnLayout->setAlignment(Qt::AlignBottom | Qt::AlignHCenter);
     btnLayout->addWidget(m_addCustomShortcut);
     vlayout->addLayout(btnLayout);
-    vlayout->setContentsMargins(10, 10, 10, 5);
+    vlayout->setContentsMargins(10, 10, 0, 5);
     setLayout(vlayout);
 
     connect(m_addCustomShortcut, &DFloatingButton::clicked, this, &ShortCutSettingWidget::customShortcut);
