@@ -105,6 +105,7 @@ PersonalizationGeneral::PersonalizationGeneral(QWidget *parent)
     , m_wmSwitch(nullptr)
     , m_transparentSlider(nullptr)
     , m_cmbMiniEffect(new ComboxWidget)
+    , m_winRoundSlider(nullptr)
     , m_Themes(new PerssonalizationThemeWidget())
     , m_bgWidget(new RingColorWidget)
     , m_switchWidget(new QWidget)
@@ -113,6 +114,7 @@ PersonalizationGeneral::PersonalizationGeneral(QWidget *parent)
     m_centralLayout->setContentsMargins(ThirdPageContentsMargins);
     //appearance
     //~ contents_path /personalization/General
+    //~ child_page General
     TitleLabel *themeL = new TitleLabel(tr("Theme"));
     m_centralLayout->addWidget(themeL);
     //pictures and types
@@ -123,6 +125,7 @@ PersonalizationGeneral::PersonalizationGeneral(QWidget *parent)
 
     //active colors
     //~ contents_path /personalization/General
+    //~ child_page General
     TitleLabel *activeL = new TitleLabel(tr("Accent Color"));
     m_centralLayout->addWidget(activeL);
 
@@ -171,6 +174,7 @@ PersonalizationGeneral::PersonalizationGeneral(QWidget *parent)
         QVBoxLayout *winEffectVLayout = new QVBoxLayout();
         winEffectVLayout->addSpacing(20);
         m_switchWidget->setLayout(winEffectVLayout);
+        m_switchWidget->setAccessibleName("switchWidget");
 
         m_wmSwitch = new DSwitchButton();
         m_wmSwitch->setAccessibleName("switchbutton");
@@ -181,6 +185,7 @@ PersonalizationGeneral::PersonalizationGeneral(QWidget *parent)
         switem->setLayout(swswitchLayout);
 
         //~ contents_path /personalization/General
+        //~ child_page General
         swswitchLayout->addWidget(new QLabel(tr("Window Effect")));
         swswitchLayout->addStretch();
         swswitchLayout->addWidget(m_wmSwitch);
@@ -190,6 +195,7 @@ PersonalizationGeneral::PersonalizationGeneral(QWidget *parent)
         winEffectVLayout->addSpacing(10);
 
         //~ contents_path /personalization/General
+        //~ child_page General
         m_transparentSlider = new dcc::widgets::TitledSliderItem(tr("Transparency"));
         //transparancy switch
         m_transparentSlider->addBackground();
@@ -210,6 +216,8 @@ PersonalizationGeneral::PersonalizationGeneral(QWidget *parent)
         winEffectVLayout->addWidget(m_transparentSlider);
         winEffectVLayout->addSpacing(10);
 
+        //~ contents_path /personalization/General
+        //~ child_page General
         m_cmbMiniEffect->setTitle(tr("Window Minimize Effect"));
         m_cmbMiniEffect->addBackground();
         QStringList options;
@@ -270,11 +278,13 @@ PersonalizationGeneral::PersonalizationGeneral(QWidget *parent)
     m_centralLayout->addStretch(20);
 
     QScrollArea *scrollArea = new QScrollArea;
+    scrollArea->setAccessibleName("PersonalizationGeneral_scrollArea");
     scrollArea->setWidgetResizable(true);
     scrollArea->setFrameStyle(QFrame::NoFrame);
     scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     scrollArea->setContentsMargins(0, 0, 0, 0);
+    scrollArea->setBackgroundRole(QPalette::Base);
 
     QVBoxLayout *mainContentLayout = new QVBoxLayout;
     mainContentLayout->setAlignment(Qt::AlignTop | Qt::AlignHCenter);
@@ -282,7 +292,9 @@ PersonalizationGeneral::PersonalizationGeneral(QWidget *parent)
     mainContentLayout->addWidget(scrollArea);
 
     auto tw = new QWidget();
+    tw->setAccessibleName("centralLayoutWidget");
     tw->setLayout(m_centralLayout);
+    m_centralLayout->setContentsMargins(0, 0, 0, 0);
     scrollArea->setWidget(tw);
 }
 
