@@ -60,22 +60,41 @@ static QGSettings *GSettings()
 GeneralWidget::GeneralWidget(QWidget *parent, bool bIsBattery)
     : QWidget(parent)
     , m_bIsBattery(bIsBattery)
-    , m_layout(new QVBoxLayout)
-    , m_swLowPowerAutoIntoSaveEnergyMode(new SwitchWidget(tr("Auto power saving on low battery")))
-    , m_autoIntoSaveEnergyMode(new SwitchWidget(tr("Auto power saving on battery")))
-    , m_sldLowerBrightness(new TitledSliderItem(tr("Decrease brightness"), this))
-    , m_wakeComputerNeedPassword(new SwitchWidget(tr("Password is required to wake up the computer")))
-    , m_wakeDisplayNeedPassword(new SwitchWidget(tr("Password is required to wake up the monitor")))
-    , m_batteryLabel(new TitleLabel(tr("Battery")))
-    , m_powerShowTimeToFull(new SwitchWidget(tr("Display remaining using and charging time")))
-    , m_ShowTimeToFullTips(new PowerDisplayWidget(tr("Maximum capacity"), this))
-    , m_showBatteryCapacity(new SwitchWidget(tr("Show battery capacity")))
+    , m_layout(new QVBoxLayout(this))
+    , m_batteryLabel(nullptr)
     , m_batteryCapacity(new TitleValueItem)
 {
+    //~ contents_path /power/General
+    //~ child_page General
     m_powerPlanMap.insert(BALANCE, tr("Balanced"));
+    //~ contents_path /power/General
+    //~ child_page General
     m_powerPlanMap.insert(PERFORMANCE, tr("High Performance"));
+    //~ contents_path /power/General
+    //~ child_page General
     m_powerPlanMap.insert(POWERSAVE, tr("Power Saver"));
 
+    //~ contents_path /power/General
+    //~ child_page General
+    m_swLowPowerAutoIntoSaveEnergyMode = new SwitchWidget(tr("Auto power saving on low battery"), this);
+    //~ contents_path /power/General
+    //~ child_page General
+    m_autoIntoSaveEnergyMode = new SwitchWidget(tr("Auto power saving on battery"), this);
+    //~ contents_path /power/General
+    //~ child_page General
+    m_sldLowerBrightness = new TitledSliderItem(tr("Decrease brightness"), this);
+    //~ contents_path /power/General
+    //~ child_page General
+    m_wakeComputerNeedPassword = new SwitchWidget(tr("Password is required to wake up the computer"), this);
+    //~ contents_path /power/General
+    //~ child_page General
+    m_wakeDisplayNeedPassword = new SwitchWidget(tr("Password is required to wake up the monitor"), this);
+    //~ contents_path /power/General
+    //~ child_page General
+    m_powerShowTimeToFull = new SwitchWidget(tr("Display remaining using and charging time"), this);
+    //~ contents_path /power/General
+    //~ child_page General
+    m_ShowTimeToFullTips = new PowerDisplayWidget(tr("Maximum capacity"), this);
     initUi();
 
     connect(m_powerplanListview, &DListView::clicked, this, &GeneralWidget::onPowerPlanChanged);
@@ -106,11 +125,13 @@ void GeneralWidget::initUi()
 
     /**** 性能设置 ************************************************************************/
     //~ contents_path /power/General
-    TitleLabel *powerPlansLabel = new TitleLabel(tr("Power Plans"));                            // 性能设置label
+    //~ child_page General
+    TitleLabel *powerPlansLabel = new TitleLabel(tr("Power Plans"), this);                            // 性能设置label
     DFontSizeManager::instance()->bind(powerPlansLabel, DFontSizeManager::T5, QFont::DemiBold); // 性能设置label字体
     GSettingWatcher::instance()->bind("powerPlansLabel", powerPlansLabel);                      // 使用GSettings来控制显示状态
-    QVBoxLayout *powerPlansLayout = new QVBoxLayout;                                            // 性能模式布局
-    m_powerplanListview = new DListView();                                                      // 电源模式列表
+    QVBoxLayout *powerPlansLayout = new QVBoxLayout(this);                                            // 性能模式布局
+    m_powerplanListview = new DListView(this);                                                        // 电源模式列表
+    m_powerplanListview->setAccessibleName("powerplanListview");
 
     m_powerPlanModel = new QStandardItemModel(m_powerplanListview);
     QMap<QString, QString>::iterator iter;
@@ -130,6 +151,9 @@ void GeneralWidget::initUi()
     m_powerplanListview->setSelectionMode(QAbstractItemView::NoSelection);
 
     powerPlansLabel->setContentsMargins(10, 0, 10, 0);  // 性能设置label与外面布局的边距
+    QMargins itemMargins(m_powerplanListview->itemMargins()); // 添加性能模式标题间隔
+    itemMargins.setLeft(2); //dtk控件里面自带文字左间距8,这里设置2就足够10
+    m_powerplanListview->setItemMargins(itemMargins);
     powerPlansLayout->addWidget(powerPlansLabel);       // 添加性能设置label
     powerPlansLayout->addWidget(m_powerplanListview);   // 添加性能模式列表
     powerPlansLayout->setSpacing(10);                   // 布局中组件间距
@@ -139,15 +163,17 @@ void GeneralWidget::initUi()
 
     /**** 节能设置 ************************************************************************/
     //~ contents_path /power/General
-    TitleLabel *energySavingLabel = new TitleLabel(tr("Power Saving Settings"));                  // 节能设置label
+    //~ child_page General
+    TitleLabel *energySavingLabel = new TitleLabel(tr("Power Saving Settings"), this);                  // 节能设置label
     DFontSizeManager::instance()->bind(energySavingLabel, DFontSizeManager::T5, QFont::DemiBold); // 节能设置label字体
-    QVBoxLayout *energySavingLayout = new QVBoxLayout;                                            // 节能设置布局
+    QVBoxLayout *energySavingLayout = new QVBoxLayout(this);                                            // 节能设置布局
     GSettingWatcher::instance()->bind("powerLowerBrightness", energySavingLabel);                 // 使用GSettings来控制显示状态
     SettingsGroup *energySavingGrp = new SettingsGroup;
 
     QStringList annotions;
     annotions << "10%" << "20%" << "30%" << "40%";
 
+    m_sldLowerBrightness->slider()->setAccessibleName("sldLowerBrightness");
     m_sldLowerBrightness->slider()->setAnnotations(annotions);
     m_sldLowerBrightness->slider()->setRange(1, 4);
     m_sldLowerBrightness->slider()->setPageStep(10);
@@ -172,9 +198,10 @@ void GeneralWidget::initUi()
 
     /**** 唤醒设置 ************************************************************************/
     //~ contents_path /power/General
-    TitleLabel *wakeupLabel = new TitleLabel(tr("Wakeup Settings"));                        // 唤醒设置label
+    //~ child_page General
+    TitleLabel *wakeupLabel = new TitleLabel(tr("Wakeup Settings"), this);                        // 唤醒设置label
     DFontSizeManager::instance()->bind(wakeupLabel, DFontSizeManager::T5, QFont::DemiBold); // 唤醒设置label字体
-    QVBoxLayout *wakeupLayout = new QVBoxLayout;                                            // 唤醒设置布局
+    QVBoxLayout *wakeupLayout = new QVBoxLayout(this);                                          // 唤醒设置布局
     SettingsGroup *wakeupSettingsGrp = new SettingsGroup;
 
     wakeupSettingsGrp->appendItem(m_wakeComputerNeedPassword);
@@ -191,9 +218,10 @@ void GeneralWidget::initUi()
 
     /**** 电池设置 ************************************************************************/
     //~ contents_path /power/General
-    m_batteryLabel = new TitleLabel(tr("Battery"));
+    //~ child_page General
+    m_batteryLabel = new TitleLabel(tr("Battery"), this);
     DFontSizeManager::instance()->bind(m_batteryLabel, DFontSizeManager::T5, QFont::DemiBold); // 电池设置label字体
-    QVBoxLayout *batteyLayout = new QVBoxLayout;                                               // 电池设置布局
+    QVBoxLayout *batteyLayout = new QVBoxLayout(this);                                               // 电池设置布局
     SettingsGroup *batterySettingsGrp = new SettingsGroup;
 
     QDBusInterface powerInter("com.deepin.system.Power", "/com/deepin/system/Power", "com.deepin.system.Power", QDBusConnection::systemBus());
@@ -220,14 +248,16 @@ void GeneralWidget::initUi()
 
     m_layout->setSpacing(30);
     m_layout->setAlignment(Qt::AlignTop);
-    m_layout->setContentsMargins(0, 10, 0, 5); // 总布局上下边距
+    m_layout->setContentsMargins(0, 2, 0, 5); // 总布局上下边距
 
-    ContentWidget *contentWgt = new ContentWidget;
-    QWidget *mainWgt = new TranslucentFrame; // 添加一层半透明框架
+    ContentWidget *contentWgt = new ContentWidget(this);
+    contentWgt->setAccessibleName("General_ContentWidget");
+    QWidget *mainWgt = new TranslucentFrame(this); // 添加一层半透明框架
     mainWgt->setLayout(m_layout);
     contentWgt->setContent(mainWgt);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(contentWgt);
+    mainLayout->setContentsMargins(0, 8, 0, 8); // 圆角
     setLayout(mainLayout);
 }
 
@@ -241,7 +271,7 @@ void GeneralWidget::setModel(const PowerModel *model)
 #endif
     connect(model, &PowerModel::suspendChanged, m_wakeComputerNeedPassword, &SwitchWidget::setVisible);
 
-    connect(model, &PowerModel::highPerformaceChanged, this, &GeneralWidget::onHighPerformanceSupportChanged);
+    connect(model, &PowerModel::highPerformaceSupportChanged, this, &GeneralWidget::onHighPerformanceSupportChanged);
     onHighPerformanceSupportChanged(model->isHighPerformanceSupported());
 
     connect(model, &PowerModel::powerPlanChanged, this, &GeneralWidget::onCurPowerPlanChanged);
@@ -257,7 +287,7 @@ void GeneralWidget::setModel(const PowerModel *model)
     m_autoIntoSaveEnergyMode->setChecked(model->autoPowerSaveMode());
 #endif
 
-    m_wakeComputerNeedPassword->setVisible(model->canSleep() && model->getSuspend()
+    m_wakeComputerNeedPassword->setVisible(model->canSuspend() && model->getSuspend()
                                                              && (GSettingWatcher::instance()->getStatus("systemSuspend") != "Hidden"));
 
     //-------------sp2 add-------------------------
@@ -272,7 +302,9 @@ void GeneralWidget::setModel(const PowerModel *model)
     m_sldLowerBrightness->setVisible(maxBacklight >= 100 || maxBacklight == 0);
     m_sldLowerBrightness->slider()->setValue(model->powerSavingModeLowerBrightnessThreshold() / 10);
     connect(model, &PowerModel::powerSavingModeLowerBrightnessThresholdChanged, this,  [ = ](const uint dLevel) {
+        m_sldLowerBrightness->slider()->blockSignals(true);
         m_sldLowerBrightness->slider()->setValue(dLevel / 10);
+        m_sldLowerBrightness->slider()->blockSignals(false);
     });
 
     bool bStatus = model->haveBettary();
@@ -346,10 +378,15 @@ void GeneralWidget::onHighPerformanceSupportChanged(const bool isSupport)
 {
     int row_count = m_powerPlanModel->rowCount();
     if (!isSupport) {
+        int cur_place = m_powerplanListview->currentIndex().row();
         for (int i = 0; i < row_count; ++i) {
             QStandardItem *items = m_powerPlanModel->item(i, 0);
             if (items->data(PowerPlanRole).toString() == PERFORMANCE) {
                 m_powerPlanModel->removeRow(i);
+
+                if (cur_place == i || cur_place < 0) {
+                    m_powerplanListview->clicked(m_powerPlanModel->index(0, 0));
+                }
                 break;
             }
         }
