@@ -27,6 +27,7 @@
 #include "widgets/switchwidget.h"
 #include "widgets/settingsgroup.h"
 #include "modules/power/powermodel.h"
+#include "modules/power/powerworker.h"
 #include "window/utils.h"
 #include "window/gsettingwatcher.h"
 #include "widgets/comboxwidget.h"
@@ -42,18 +43,11 @@ using namespace dcc::power;
 using namespace DCC_NAMESPACE;
 using namespace DCC_NAMESPACE::power;
 
-UseBatteryWidget::UseBatteryWidget(PowerModel *model, QWidget *parent)
+UseBatteryWidget::UseBatteryWidget(PowerModel *model, QWidget *parent, dcc::power::PowerWorker *worker)
     : QWidget(parent)
     , m_layout(new QVBoxLayout)
-    , m_monitorSleepOnBattery(new TitledSliderItem(tr("Monitor will suspend after")))
-    , m_computerSleepOnBattery(new TitledSliderItem(tr("Computer will suspend after")))
-    , m_autoLockScreen(new TitledSliderItem(tr("Lock screen after")))
-    , m_cmbPowerBtn(new ComboxWidget(tr("When pressing the power button")))
-    , m_cmbCloseLid(new ComboxWidget(tr("When the lid is closed")))
-    , m_swBatteryHint(new SwitchWidget(tr("Low Battery Notification")))
-    , m_sldLowBatteryHint(new TitledSliderItem(tr("Low battery level")))
-    , m_sldAutoSuspend(new TitledSliderItem(tr("Auto suspend battery level")))
-//    , m_suspendOnLidClose(new SwitchWidget(tr("Suspend on lid close")))
+    , m_model(model)
+    , m_work(worker)
 {
     setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
     QStringList options;
@@ -65,6 +59,30 @@ UseBatteryWidget::UseBatteryWidget(PowerModel *model, QWidget *parent)
           << "30m"
           << "1h" << tr("Never");
 
+    //~ contents_path /power/On Battery
+    //~ child_page On Battery
+    m_monitorSleepOnBattery = new TitledSliderItem(tr("Monitor will suspend after"));
+    //~ contents_path /power/On Battery
+    //~ child_page On Battery
+    m_computerSleepOnBattery = new TitledSliderItem(tr("Computer will suspend after"));
+    //~ contents_path /power/On Battery
+    //~ child_page On Battery
+    m_autoLockScreen = new TitledSliderItem(tr("Lock screen after"));
+    //~ contents_path /power/On Battery
+    //~ child_page On Battery
+    m_cmbPowerBtn = new ComboxWidget(tr("When pressing the power button"));
+    //~ contents_path /power/On Battery
+    //~ child_page On Battery
+    m_cmbCloseLid = new ComboxWidget(tr("When the lid is closed"));
+    //~ contents_path /power/On Battery
+    //~ child_page On Battery
+    m_swBatteryHint = new SwitchWidget(tr("Low Battery Notification"));
+    //~ contents_path /power/On Battery
+    //~ child_page On Battery
+    m_sldLowBatteryHint = new TitledSliderItem(tr("Low battery level"));
+    //~ contents_path /power/On Battery
+    //~ child_page On Battery
+    m_sldAutoSuspend = new TitledSliderItem(tr("Auto suspend battery level"));
     /*** 超时关闭显示器 ***/
     //~ contents_path /power/On Battery
     //~ child_page On Battery
@@ -104,26 +122,7 @@ UseBatteryWidget::UseBatteryWidget(PowerModel *model, QWidget *parent)
     m_autoLockScreen->addBackground();
     m_layout->addWidget(m_autoLockScreen);
 
-    //~ contents_path /power/On Battery
-    //~ child_page On Battery
-//    m_suspendOnLidClose->setAccessibleName(tr("Suspend on lid close"));
-
-    /*** 笔记本合盖功能与按电源按钮功能 ***/
-    if (model->getShutdown()) {
-        options << tr("Shut down");
-    }
-    if (model->getSuspend()) {
-        options << tr("Suspend");
-    }
-    if (model->getHibernate()) {
-        options << tr("Hibernate");
-    }
-    options << tr("Turn off the monitor") << tr("Do nothing");
-    m_cmbPowerBtn->setComboxOption(options);
-    m_cmbPowerBtn->addBackground();
-    options.pop_front();
-    m_cmbCloseLid->setComboxOption(options);
-    m_cmbCloseLid->addBackground();
+    updatePowerButtonActionList();
 
     m_layout->addWidget(m_cmbCloseLid);
     m_layout->addWidget(m_cmbPowerBtn);
@@ -138,14 +137,19 @@ UseBatteryWidget::UseBatteryWidget(PowerModel *model, QWidget *parent)
     SettingsGroup *lowBatteryGrp = new SettingsGroup(nullptr, SettingsGroup::GroupBackground);
     lowBatteryGrp->layout()->setContentsMargins(0, 0, 0, 0);
     options.clear();
-    for (int i = 0; i <= 9; i++) {
+    for (int i = 0; i <= 3; i++) {
         options.append(QString());
     }
-    options[0] = "16%";
-    options[4] = "20%";
-    options[9] = "25%";
+    options[0] = "10%";
+    options[1] = "15%";
+    options[2] = "20%";
+    options[3] = "25%";
     m_sldLowBatteryHint->setAnnotations(options);
-    m_sldLowBatteryHint->slider()->setRange(16, 25);
+    m_sldLowBatteryMap.insert(0, 10);
+    m_sldLowBatteryMap.insert(1, 15);
+    m_sldLowBatteryMap.insert(2, 20);
+    m_sldLowBatteryMap.insert(3, 25);
+    m_sldLowBatteryHint->slider()->setRange(0, 3);
     m_sldLowBatteryHint->slider()->setType(DCCSlider::Vernier);
     m_sldLowBatteryHint->slider()->setTickPosition(QSlider::NoTicks);
     lowBatteryGrp->appendItem(m_swBatteryHint);
@@ -168,15 +172,17 @@ UseBatteryWidget::UseBatteryWidget(PowerModel *model, QWidget *parent)
     /*********************/
     m_layout->setAlignment(Qt::AlignTop);
     m_layout->setSpacing(10);
-    m_layout->setContentsMargins(10, 10, 10, 5);
+    m_layout->setContentsMargins(10, 10, 2, 5);
 
     //add scroll
     ContentWidget *contentWgt = new ContentWidget;
+    contentWgt->setAccessibleName("UseBatteryWidget_Content");
     QWidget *mainWgt = new TranslucentFrame;
     mainWgt->setLayout(m_layout);
     contentWgt->setContent(mainWgt);
     QVBoxLayout *mainLayout = new QVBoxLayout;
     mainLayout->addWidget(contentWgt);
+    mainLayout->setContentsMargins(0, 0, 8, 8);
     setLayout(mainLayout);
 
     setModel(model);
@@ -185,7 +191,11 @@ UseBatteryWidget::UseBatteryWidget(PowerModel *model, QWidget *parent)
     connect(m_computerSleepOnBattery->slider(), &DCCSlider::valueChanged, this, &UseBatteryWidget::requestSetSleepDelayOnBattery);
     connect(m_autoLockScreen->slider(), &DCCSlider::valueChanged, this, &UseBatteryWidget::requestSetAutoLockScreenOnBattery);
 
-
+    connect(m_cmbPowerBtn->comboBox(), &AlertComboBox::clicked, this, [ = ]() {
+        updatePowerButtonActionList();
+        setPowerBtn(model, model->batteryPressPowerBtnAction());
+        setCloseLid(model, model->batteryLidClosedAction());
+    });
 
     connect(m_cmbPowerBtn, &ComboxWidget::onIndexChanged, this, [ = ](int nIndex) {
         if (!model->getSuspend()) {
@@ -202,6 +212,12 @@ UseBatteryWidget::UseBatteryWidget(PowerModel *model, QWidget *parent)
             }
         }
     });
+
+    connect(m_cmbCloseLid->comboBox(), &AlertComboBox::clicked, this, [ = ]() {
+        updatePowerButtonActionList();
+        setPowerBtn(model, model->batteryPressPowerBtnAction());
+        setCloseLid(model, model->batteryLidClosedAction());
+    });
     connect(m_cmbCloseLid, &ComboxWidget::onIndexChanged, [ = ](int nIndex) {
         if (!model->getSuspend()) {
             if (!model->getHibernate()) {
@@ -249,10 +265,10 @@ void UseBatteryWidget::setModel(const PowerModel *model)
 //    m_suspendOnLidClose->setChecked(model->sleepOnLidOnBatteryClose());
     setAutoLockScreenOnBattery(model->getBatteryLockScreenDelay());
 
-    m_computerSleepOnBattery->setVisible(model->canSleep() && model->getSuspend()
+    m_computerSleepOnBattery->setVisible(model->canSuspend() && model->getSuspend()
                                                            && (GSettingWatcher::instance()->getStatus("systemSuspend") != "Hidden"));
     m_sldAutoSuspend->setVisible(model->getSuspend() && (GSettingWatcher::instance()->getStatus("systemSuspend") != "Hidden"));
-//    m_suspendOnLidClose->setVisible(model->canSleep());
+//    m_suspendOnLidClose->setVisible(model->canSuspend());
 
     //--------------sp2 add-----------------
     m_cmbCloseLid->setVisible(model->lidPresent() && GSettingWatcher::instance()->getStatus("powerLidPresent") != "Hidden");
@@ -276,7 +292,9 @@ void UseBatteryWidget::setModel(const PowerModel *model)
     onLowPowerNotifyThreshold(model->lowPowerNotifyThreshold());
     connect(model, &PowerModel::lowPowerNotifyThresholdChanged, this, &UseBatteryWidget::onLowPowerNotifyThreshold);
     connect(m_sldLowBatteryHint->slider(), &DCCSlider::valueChanged, this, [ = ](int value) {
-        Q_EMIT  requestSetLowPowerNotifyThreshold(value);
+        if (m_sldLowBatteryMap.contains(value)) {
+            Q_EMIT  requestSetLowPowerNotifyThreshold(m_sldLowBatteryMap[value]);
+        }
     });
 
     onLowPowerAutoSleepThreshold(model->lowPowerAutoSleepThreshold());
@@ -313,10 +331,22 @@ void UseBatteryWidget::setAutoLockScreenOnBattery(const int delay)
 
 void UseBatteryWidget::onLowPowerNotifyThreshold(const int value)
 {
-    m_sldLowBatteryHint->slider()->blockSignals(true);
-    m_sldLowBatteryHint->slider()->setValue(value);
-    m_sldLowBatteryHint->setValueLiteral(QString("%1%").arg(value));
-    m_sldLowBatteryHint->slider()->blockSignals(false);
+    int index = -1;
+    QMap<int, int>::iterator iter = m_sldLowBatteryMap.begin();
+    while (iter != m_sldLowBatteryMap.end())
+    {
+        if (iter.value() == value) {
+            index = iter.key();
+            break;
+        }
+        ++iter;
+    }
+    if (index >= 0) {
+        m_sldLowBatteryHint->slider()->blockSignals(true);
+        m_sldLowBatteryHint->slider()->setValue(index);
+        m_sldLowBatteryHint->setValueLiteral(QString("%1%").arg(value));
+        m_sldLowBatteryHint->slider()->blockSignals(false);
+    }
 }
 
 void UseBatteryWidget::onLowPowerAutoSleepThreshold(const int value)
@@ -361,6 +391,31 @@ void UseBatteryWidget::setPowerBtn(const dcc::power::PowerModel *model, int powI
     }
 }
 
+void UseBatteryWidget::updatePowerButtonActionList()
+{
+    if (!m_model) {
+        return;
+    }
+
+    QStringList options;
+    /*** 笔记本合盖功能与按电源按钮功能 ***/
+    if (m_model->getShutdown()) {
+        options << tr("Shut down");
+    }
+    if (m_work->getCurCanSuspend()) {
+        options << tr("Suspend");
+    }
+    if (m_work->getCurCanHibernate()) {
+        options << tr("Hibernate");
+    }
+    options << tr("Turn off the monitor") << tr("Do nothing");
+    m_cmbPowerBtn->setComboxOption(options);
+    m_cmbPowerBtn->addBackground();
+    options.pop_front();
+    m_cmbCloseLid->setComboxOption(options);
+    m_cmbCloseLid->addBackground();
+}
+
 QString UseBatteryWidget::delayToLiteralString(const int delay) const
 {
     QString strData = "";
