@@ -57,46 +57,52 @@ SpeakerPage::SpeakerPage(QWidget *parent)
     , m_speakSlider(nullptr)
     , m_vbWidget(nullptr)
     , m_balanceSlider(nullptr)
-    , m_lastsetvalue(0)
+    , m_waitTimerValue(0)
+    , m_lastRmPortIndex(-1)
     , m_balance(true)
     , m_volumeBtn(nullptr)
     , m_mute(false)
     , m_enablePort(false)
+    , m_fristChangePort(true)
+    , m_fristStatusChangePort(true)
+    , m_waitStatusChangeTimer(new QTimer (this))
 {
     const int titleLeftMargin = 8;
+
+    //~ contents_path /sound/Output
+    //~ child_page Output
     TitleLabel *labelOutput = new TitleLabel(tr("Output"));
     DFontSizeManager::instance()->bind(labelOutput, DFontSizeManager::T5, QFont::DemiBold);
     labelOutput->setContentsMargins(titleLeftMargin, 0, 0, 0);
     labelOutput->setAlignment(Qt::AlignLeft | Qt::AlignTop);
 
+    //~ contents_path /sound/Output
+    //~ child_page Output
     m_outputSoundCbx = new ComboxWidget(tr("Output Device"));
-
     m_outputModel  = new QStandardItemModel(m_outputSoundCbx->comboBox());
     m_outputSoundCbx->comboBox()->setModel(m_outputModel);
-    SettingsGroup *outputSoundsGrp = new SettingsGroup(nullptr, SettingsGroup::GroupBackground);
-    outputSoundsGrp->getLayout()->setContentsMargins(ThirdPageCmbMargins);
-    outputSoundsGrp->appendItem(m_outputSoundCbx);
-    if (outputSoundsGrp->layout())
-        outputSoundsGrp->layout()->setContentsMargins(ThirdPageCmbMargins);
+    m_outputSoundCbx->comboBox()->setAccessibleName("outputSoundCbx");
 
-    QHBoxLayout *hlayout = new QHBoxLayout;
-    TitleLabel *lblTitle = new TitleLabel(tr("On"));
-    DFontSizeManager::instance()->bind(lblTitle, DFontSizeManager::T6);
-    m_sw = new SwitchWidget(nullptr, lblTitle);
-    m_sw->addBackground();
-    m_sw->setAccessibleName(tr("Speaker"));
-    hlayout->addWidget(m_sw);
+    m_outputSoundsGrp = new SettingsGroup(nullptr, SettingsGroup::GroupBackground);
+
+    //~ contents_path /sound/Output
+    //~ child_page Output
+    m_blueSoundCbx = new ComboxWidget(tr("Mode"));
+    m_blueSoundCbx->comboBox()->setAccessibleName("blueSoundCbx");
 
     m_layout->addWidget(labelOutput);
-    m_layout->addWidget(outputSoundsGrp);
-
     m_layout->setContentsMargins(ThirdPageContentsMargins);
-    m_layout->addLayout(hlayout);
+    m_waitStatusChangeTimer->setSingleShot(true);
+    connect(m_waitStatusChangeTimer, &QTimer::timeout, this, [ = ] {
+        refreshActivePortShow(m_currentPort);
+        showWaitSoundPortStatus(true);
+    });
     setLayout(m_layout);
 }
 
 SpeakerPage::~SpeakerPage()
 {
+    m_waitStatusChangeTimer->stop();
     GSettingWatcher::instance()->erase("soundOutputSlider");
     GSettingWatcher::instance()->erase("soundVolumeBoost");
     GSettingWatcher::instance()->erase("soundBalanceSlider");
@@ -105,30 +111,25 @@ SpeakerPage::~SpeakerPage()
 void SpeakerPage::setModel(dcc::sound::SoundModel *model)
 {
     m_model = model;
+    m_waitTimerValue = m_model->currentWaitSoundReceiptTime();
 
-    //当扬声器状态发生变化，将switch设置为对应的状态
+    //当扬声器状态发生变化，更新设备信息显示状态
     connect(m_model, &SoundModel::isPortEnableChanged, this, [ = ](bool visible) {
-        if (visible) {
-            m_sw->setChecked(true);
-            //启用端口后需要再判断是否启用成功后，再设置为默认端口，但因为设置端口后会有端口是否启用的状态判断，
-            //导致进入死循环，所以添加判断值，判断是否是启用或禁用端口类型的操作，若是，则设置默认端口
-            if (m_enablePort) {
-                QModelIndex index = m_outputSoundCbx->comboBox()->view()->currentIndex();
-                if (index.isValid())
-                    Q_EMIT requestSetPort(m_outputModel->data(index, Qt::WhatsThisPropertyRole).value<const dcc::sound::Port *>());
+        Q_UNUSED(visible);
+        //启用端口后需要再判断是否启用成功后，再设置为默认端口，但因为设置端口后会有端口是否启用的状态判断，
+        //导致进入死循环，所以添加判断值，判断是否是启用或禁用端口类型的操作，若是，则设置默认端口
+        if (m_enablePort) {
+            QModelIndex index = m_outputSoundCbx->comboBox()->view()->currentIndex();
+            if (index.isValid()) {
+                Q_EMIT requestSetPort(m_outputModel->data(index, Qt::WhatsThisPropertyRole).value<const dcc::sound::Port *>());
             }
         }
-        else
-            m_sw->setChecked(false);
         showDevice();
     });
 
     connect(m_model, &SoundModel::setPortChanged, this, [ = ](const dcc::sound::Port  * port) {
-        m_currentPort = port;
-        if (!m_currentPort)
-            return;
         m_enablePort = false;
-        m_sw->setHidden(!m_model->isShow(m_outputModel, m_currentPort));
+
         Q_EMIT m_model->requestSwitchEnable(port->cardId(), port->id());//设置端口后，发送信号，判断该端口是否需要禁用
     });
 
@@ -137,69 +138,87 @@ void SpeakerPage::setModel(dcc::sound::SoundModel *model)
         addPort(port);
     }
 
-    //连接switch点击信号，发送切换开/关扬声器的请求信号
-    connect(m_sw, &SwitchWidget::checkedChanged, this, [ = ] {
-        if(m_currentPort != nullptr) {
-            m_enablePort = true;
-            Q_EMIT m_model->requestSwitchSetEnable(m_currentPort->cardId(), m_currentPort->id(), m_sw->checked());
+    connect(m_outputSoundCbx->comboBox(), static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &SpeakerPage::changeComboxIndex, Qt::QueuedConnection);
+    connect(m_model, &SoundModel::bluetoothModeOptsChanged, this, [ = ](const QStringList bluetoothModeOpts){
+        if (m_bluetoothModeOpts != bluetoothModeOpts) {
+            m_bluetoothModeOpts = bluetoothModeOpts;
+            m_blueSoundCbx->comboBox()->clear(); // 先清除避免重复
+            m_blueSoundCbx->comboBox()->addItems(m_bluetoothModeOpts);
         }
-        else
-            m_sw->setChecked(false);
     });
-
-    connect(m_model, &SoundModel::portAdded, this, &SpeakerPage::addPort);
     connect(m_model, &SoundModel::portRemoved, this, &SpeakerPage::removePort);
-    connect(m_outputSoundCbx->comboBox(), static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &SpeakerPage::changeComboxIndex);
-    connect(m_model, &SoundModel::setBlanceVisible, this, [ = ](bool flag) {
-            m_balance = flag;
-            showDevice();
+    connect(m_model, &SoundModel::portAdded, this, &SpeakerPage::addPort);
+    connect(m_model, &SoundModel::soundDeviceStatusChanged, this, &SpeakerPage::changeComboxStatus, Qt::UniqueConnection);
+    connect(m_model, &SoundModel::bluetoothModeChanged, this, [ = ](const QString &mode) {
+        m_blueSoundCbx->setCurrentText(mode);
+        m_balance = !mode.contains("headset");
+        changeComboxStatus();
     });
     connect(m_model, &SoundModel::speakerOnChanged, this, [ = ](bool flag) {
-            m_mute = flag;
-            refreshIcon();
+        m_mute = flag;
+        refreshIcon();
     });
 
     initSlider();
-
-    if (m_currentPort)
-        m_sw->setHidden(!m_model->isShow(m_outputModel, m_currentPort));
-
-    if (m_outputModel->rowCount() < 2)
-        m_sw->setHidden(true);
-    requestBalanceVisible();
+    initCombox();
 }
 
-void SpeakerPage::removePort(const QString &portId, const uint &cardId)
+void SpeakerPage::removePort(const QString &portId, const uint &cardId, const dcc::sound::Port::Direction &direction)
 {
-    auto rmFunc = [ = ](QStandardItemModel * model) {
-        for (int i = 0; i < model->rowCount();) {
-            auto item = model->item(i);
-            auto port = item->data(Qt::WhatsThisPropertyRole).value<const dcc::sound::Port *>();
-            if (port->id() == portId && cardId == port->cardId()) {
-                disconnect(m_outputSoundCbx->comboBox(), static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &SpeakerPage::changeComboxIndex);
-                m_outputSoundCbx->comboBox()->hidePopup();
-                model->removeRow(i);
-                connect(m_outputSoundCbx->comboBox(), static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &SpeakerPage::changeComboxIndex);
-            } else {
-                ++i;
-            }
-        }
-    };
+    if (direction != dcc::sound::Port::Direction::Out)
+        return;
 
-    rmFunc(m_outputModel);
-    if (m_currentPort)
-        m_sw->setHidden(!m_model->isShow(m_outputModel, m_currentPort));
+    // 先阻塞m_outputSoundCbx切换信号，避免移除当前端口时被动触发切换端口信号，而新的当前端口由是后端确定
+    m_outputSoundCbx->blockSignals(true);
+    m_outputSoundCbx->comboBox()->hidePopup();
+
+    // 查找移除的端口直接从model中移除，如果是当前端口直接设置为空，新的当前端口由后端确定，控制中心响应信号设置当前端口
+    for (int i = 0; i < m_outputModel->rowCount(); i++) {
+        auto item = m_outputModel->item(i);
+        auto port = item->data(Qt::WhatsThisPropertyRole).value<const dcc::sound::Port *>();
+        if (port && port->id() == portId && cardId == port->cardId()) {
+            m_outputModel->removeRow(i);
+            if (m_currentPort && m_currentPort->id() == portId && m_currentPort->cardId() == cardId) {
+                m_currentPort = nullptr;
+            }
+            break;
+        }
+    }
+
+    changeComboxStatus();
     showDevice();
+    m_outputSoundCbx->blockSignals(false);
 }
 
 void SpeakerPage::changeComboxIndex(const int idx)
 {
-    showDevice();
     if (idx < 0)
         return;
-    auto temp = m_outputModel->index(idx, 0);
-    this->requestSetPort(m_outputModel->data(temp, Qt::WhatsThisPropertyRole).value<const dcc::sound::Port *>());
-    qDebug() << "default sink index change, currentTerxt:" << m_outputSoundCbx->comboBox()->itemText(idx);
+
+    auto tFunc = [this](const int tmpIdx){
+        auto temp = m_outputModel->index(tmpIdx, 0);
+        this->requestSetPort(m_outputModel->data(temp, Qt::WhatsThisPropertyRole).value<const dcc::sound::Port *>());
+        qDebug() << "default sink index change, currentTerxt:" << m_outputSoundCbx->comboBox()->itemText(tmpIdx);
+    };
+
+    tFunc(idx);
+    changeComboxStatus();
+
+    showDevice();
+}
+
+void SpeakerPage::changeComboxStatus()
+{
+    showWaitSoundPortStatus(false);
+    if (m_fristStatusChangePort) {
+        refreshActivePortShow(m_currentPort);
+        showWaitSoundPortStatus(true);
+        m_fristStatusChangePort = false;
+    } else {
+        m_waitStatusChangeTimer->stop();
+    }
+    m_waitStatusChangeTimer->start(m_waitTimerValue);
+    showDevice();
 }
 
 void SpeakerPage::clickLeftButton()
@@ -207,45 +226,69 @@ void SpeakerPage::clickLeftButton()
     Q_EMIT requestMute();
 }
 
+void SpeakerPage::changeBluetoothMode(const int idx)
+{
+    this->requstBluetoothMode(m_blueSoundCbx->comboBox()->itemText(idx));
+}
+
+void SpeakerPage::refreshActivePortShow(const dcc::sound::Port *port)
+{
+    if (port && port->isActive()) {
+        m_outputSoundCbx->comboBox()->setCurrentText(port->name() + "(" + port->cardName() + ")");
+        setBlueModeVisible(port->isBluetoothPort() && (m_outputModel->rowCount() > 0));
+    }
+}
+
 void SpeakerPage::addPort(const dcc::sound::Port *port)
 {
-    if (port->Out == port->direction()) {
+    if (dcc::sound::Port::Out == port->direction()) {
+        qDebug() << "SpeakerPage::addPort" << port->name();
         DStandardItem *pi = new DStandardItem;
         pi->setText(port->name() + "(" + port->cardName() + ")");
-
         pi->setData(QVariant::fromValue<const dcc::sound::Port *>(port), Qt::WhatsThisPropertyRole);
 
         connect(port, &dcc::sound::Port::nameChanged, this, [ = ](const QString str) {
             pi->setText(str);
         });
-        connect(port, &dcc::sound::Port::isActiveChanged, this, [ = ](bool isActive) {
-            pi->setCheckState(isActive ? Qt::CheckState::Checked : Qt::CheckState::Unchecked);
+
+        connect(port, &dcc::sound::Port::isOutputActiveChanged, this, [ = ](bool isActive) {
+            if (pi)
+                pi->setCheckState(isActive ? Qt::CheckState::Checked : Qt::CheckState::Unchecked);
             if (isActive) {
-                disconnect(m_outputSoundCbx->comboBox(), static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &SpeakerPage::changeComboxIndex);
-                m_outputSoundCbx->comboBox()->setCurrentText(port->name() + "(" + port->cardName() + ")");
-                connect(m_outputSoundCbx->comboBox(), static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &SpeakerPage::changeComboxIndex);
+                m_currentPort = port;
+                changeComboxStatus();
             }
         });
-        disconnect(m_outputSoundCbx->comboBox(), static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &SpeakerPage::changeComboxIndex);
+        connect(port, &dcc::sound::Port::currentPortEnabled, this, [ = ](bool isEnable) {
+            int index = m_outputSoundCbx->comboBox()->findData(port);
+            // 若端口可用 且没有添加
+            if (isEnable && (index == -1) && pi) {
+                m_outputModel->appendRow(pi);
+                showDevice();
+            }
+
+            if (!isEnable && (index != -1)) {
+                m_outputModel->removeRow(index);
+                showDevice();
+            }
+        });
+
         m_outputSoundCbx->comboBox()->hidePopup();
-        m_outputModel->appendRow(pi);
-        connect(m_outputSoundCbx->comboBox(), static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &SpeakerPage::changeComboxIndex);
+        if (port->isEnabled())
+            m_outputModel->appendRow(pi);
         if (port->isActive()) {
-            disconnect(m_outputSoundCbx->comboBox(), static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &SpeakerPage::changeComboxIndex);
-            m_outputSoundCbx->comboBox()->setCurrentText(port->name() + "(" + port->cardName() + ")");
-            connect(m_outputSoundCbx->comboBox(), static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &SpeakerPage::changeComboxIndex);
             m_currentPort = port;
+            refreshActivePortShow(m_currentPort);
             Q_EMIT m_model->requestSwitchEnable(port->cardId(), port->id());
         }
-        if (m_currentPort)
-            m_sw->setHidden(!m_model->isShow(m_outputModel, m_currentPort));
         showDevice();
     }
 }
 
 void SpeakerPage::initSlider()
 {
-    //~ contents_path /sound/Speaker
+    //~ contents_path /sound/Output
+    //~ child_page Output
     m_outputSlider = new TitledSliderItem(tr("Output Volume"), this);
     m_outputSlider->addBackground();
     m_speakSlider = m_outputSlider->slider();
@@ -288,25 +331,7 @@ void SpeakerPage::initSlider()
 
     //处理滑块位置变化的槽
     auto slotfunc1 = [ = ](int pos) {
-        //当前设置音量大于上一次设置的音量时，说明音量是在增加
-        if (pos > m_lastsetvalue) {
-            //因为增加5%幅度的区间是110～120,所以要包含110,不包含120,从120开始就是1%的幅度增加
-            if (pos >= 110 && pos < 120) {
-                m_outputSlider->slider()->qtSlider()->setSingleStep(5);
-            } else {
-                m_outputSlider->slider()->qtSlider()->setSingleStep(1);
-            }
-            m_lastsetvalue = pos;
-            //当前设置音量小于上一次设置的音量时，说明音量是在降低
-        } else if (pos < m_lastsetvalue) {
-            //因为增加5%幅度的区间是110～120,所以要不包含121和110,从120～110开始就是5%的幅度降低
-            if (pos > 110 && pos < 121) {
-                m_outputSlider->slider()->qtSlider()->setSingleStep(5);
-            } else {
-                m_outputSlider->slider()->qtSlider()->setSingleStep(1);
-            }
-            m_lastsetvalue = pos;
-        }
+        m_outputSlider->slider()->qtSlider()->setSingleStep(1);
         double vals = pos / 100.0;
         //滑块位置改变时，发送设置音量的信号
         Q_EMIT requestSetSpeakerVolume(vals);
@@ -341,13 +366,16 @@ void SpeakerPage::initSlider()
         m_outputSlider->setValueLiteral(QString::number((int)(m_model->speakerVolume() * 100 + 0.000001))+ "%");
     });
     connect(m_volumeBtn, &SoundLabel::clicked, this, &SpeakerPage::clickLeftButton);
-    m_layout->insertWidget(3, m_outputSlider);
+    m_layout->insertWidget(2, m_outputSlider);
 
     //音量增强
     auto hlayout = new QVBoxLayout();
     auto volumeBoost = new SwitchWidget(this);
     volumeBoost->addBackground();
     volumeBoost->setChecked(m_model->isIncreaseVolume());
+
+    //~ contents_path /sound/Output
+    //~ child_page Output
     volumeBoost->setTitle(tr("Volume Boost"));
     connect(m_model, &SoundModel::increaseVolumeChanged, volumeBoost, &SwitchWidget::setChecked);
     connect(volumeBoost, &SwitchWidget::checkedChanged, this, &SpeakerPage::requestIncreaseVolume);
@@ -361,10 +389,14 @@ void SpeakerPage::initSlider()
     volumeBoostTip->setContentsMargins(10, 0, 0, 0);
     hlayout->addWidget(volumeBoostTip);
     m_vbWidget = new QWidget(this);
+    m_vbWidget->setAccessibleName("SpeakerPage_vbWidget");
     m_vbWidget->setLayout(hlayout);
     m_vbWidget->setVisible(m_model->isPortEnable());
-    m_layout->insertWidget(4, m_vbWidget);
-    //~ contents_path /sound/Speaker
+    m_layout->insertWidget(3, m_vbWidget);
+    m_layout->addWidget(m_vbWidget);
+
+    //~ contents_path /sound/Output
+    //~ child_page Output
     m_balanceSlider = new TitledSliderItem(tr("Left/Right Balance"), this);
     m_balanceSlider->addBackground();
 
@@ -380,6 +412,7 @@ void SpeakerPage::initSlider()
     slider2->setSliderPosition(static_cast<int>(m_model->speakerBalance() * 100 + 0.000001));
     slider2->setPageStep(1);
     m_balanceSlider->setAnnotations(balanceList);
+    m_balance = !(m_model->currentBluetoothAudioMode().contains("headset"));
 
     auto slotfunc2 = [ = ](int pos) {
         double value = pos / 100.0;
@@ -395,17 +428,34 @@ void SpeakerPage::initSlider()
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged, this, &SpeakerPage::refreshIcon);
     connect(qApp, &DApplication::iconThemeChanged, this, &SpeakerPage::refreshIcon);
 
-    m_layout->insertWidget(5, m_balanceSlider);
-    m_layout->setSpacing(10);
-    m_layout->addStretch(10);
-    refreshIcon();
-    showDevice();
+    m_layout->insertWidget(4, m_balanceSlider);
 
     // 使用GSettings来控制显示状态
     GSettingWatcher::instance()->bind("soundOutputSlider", m_outputSlider);
     GSettingWatcher::instance()->bind("soundVolumeBoost", volumeBoost);
     GSettingWatcher::instance()->bind("soundVolumeBoost", volumeBoostTip);
     GSettingWatcher::instance()->bind("soundBalanceSlider", m_balanceSlider);
+
+    refreshIcon();
+    showDevice();
+}
+
+void SpeakerPage::initCombox()
+{
+    m_blueSoundCbx->comboBox()->addItems(m_model->bluetoothAudioModeOpts());
+    m_blueSoundCbx->comboBox()->setCurrentText(m_model->currentBluetoothAudioMode());
+    connect(m_blueSoundCbx->comboBox(), static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &SpeakerPage::changeBluetoothMode);
+
+    m_outputSoundsGrp->getLayout()->setContentsMargins(ThirdPageCmbMargins);
+    m_outputSoundsGrp->appendItem(m_outputSoundCbx);
+    m_outputSoundsGrp->appendItem(m_blueSoundCbx);
+
+    if (m_outputSoundsGrp->layout())
+        m_outputSoundsGrp->layout()->setContentsMargins(ThirdPageCmbMargins);
+
+    m_layout->addWidget(m_outputSoundsGrp);
+    m_layout->setSpacing(10);
+    m_layout->addStretch(10);
 }
 
 void SpeakerPage::refreshIcon()
@@ -417,31 +467,36 @@ void SpeakerPage::refreshIcon()
     }
 }
 
+void SpeakerPage::showWaitSoundPortStatus(bool showStatus)
+{
+    if ((m_currentPort && !m_currentPort->isBluetoothPort()) || m_model->currentBluetoothAudioMode().isEmpty()) {
+        m_blueSoundCbx->setVisible(false);
+    }
+    m_outputSoundCbx->setEnabled(showStatus);
+    m_blueSoundCbx->setEnabled(showStatus);
+}
+
 /**
  * @brief SpeakerPage::showDevice
  * 当无设备时，不显示设备信息
- * 当只有一个设备时，一直显示设备信息
  * 当有多个设备，且未禁用时，显示设备信息
+ * 跟随设备管理
  */
 void SpeakerPage::showDevice()
 {
     if (!m_speakSlider || !m_vbWidget || !m_balanceSlider || !m_outputSlider)
         return;
-    if (1 == m_outputModel->rowCount())
-        setDeviceVisible(true);
-    if (1 > m_outputModel->rowCount())
+
+    if (1 > m_outputModel->rowCount()){
         setDeviceVisible(false);
-    if (1 < m_outputModel->rowCount()) {
-        if (m_sw->checked())
-            setDeviceVisible(true);
-        else
-            setDeviceVisible(false);
-    }
+        setBlueModeVisible(false);
+    } else
+        setDeviceVisible(true);
 }
 
-void SpeakerPage::setDeviceVisible(bool visable)
+void SpeakerPage::setDeviceVisible(bool visible)
 {
-    if (visable) {
+    if (visible) {
         m_speakSlider->show();
         m_vbWidget->show();
         if (GSettingWatcher::instance()->getStatus("soundBalanceSlider") != "Hidden")
@@ -455,3 +510,12 @@ void SpeakerPage::setDeviceVisible(bool visable)
         m_outputSlider->hide();
     }
 }
+
+void SpeakerPage::setBlueModeVisible(bool visible)
+{
+    // 模式的状态应该跟随 蓝牙端口显示的时机
+    m_blueSoundCbx->setVisible(visible);
+    if (visible)
+        m_blueSoundCbx->comboBox()->setCurrentText(m_model->currentBluetoothAudioMode());
+
+}
