@@ -2,6 +2,10 @@
 
 #include <gtest/gtest.h>
 
+#ifdef QT_DEBUG
+#include <sanitizer/asan_interface.h>
+#endif
+
 int main(int argc, char **argv)
 {
     setenv("QT_QPA_PLATFORM", "offscreen", 1);
@@ -9,5 +13,11 @@ int main(int argc, char **argv)
 
     ::testing::InitGoogleTest(&argc, argv);
 
-    return  RUN_ALL_TESTS();
+    int ret = RUN_ALL_TESTS();
+
+#ifdef QT_DEBUG
+    __sanitizer_set_report_path("asan_mouse.log");
+#endif
+
+    return ret;
 }
